/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.context;

/**
 * <code>ExecutionContext</code> es la interfaz pública que define cual será la
 * información del entorno de la aplicación disponible en el contexto donde esta
 * se ejecuta.
 * <p>
 * Dicha información será:
 * <ul>
 * <li>Versión de la aplicación.
 * <li>Arquetipo de la Amtega utilizado para la creación de la aplicación.
 * <li>Entorno donde se ejecuta la aplicación.
 * <li>Nombre del servidor donde se ejecuta la aplicación.
 * <li>Código de la aplicación.
 * <li>Fecha de inicio o despliegue de la aplicación.
 * </ul>
 */
public interface ExecutionContext {

    /**
     * Obtiene la versión de la aplicación.
     *
     * @return versión de la aplicación
     */
    String getVersion();

    /**
     * Obtiene la variante del arquetipo de la Amtega utilizado para la creación
     * de la aplicación.
     *
     * @return arquetipo
     */
    String getArchetypeId();

    /**
     * Obtiene la versión del arquetipo de la Amtega utilizado para la creación
     * de la aplicación.
     *
     * @return versión del arquetipo
     */
    String getArchetypeVersion();

    /**
     * Obtiene el entorno donde se ejecuta la aplicación.
     *
     * @return entorno de ejecución
     */
    String getEnvironment();

    /**
     * Obtiene el nombre del servidor donde se ejecuta la aplicación.
     *
     * @return nombre del servidor
     */
    String getServerName();

    /**
     * Obtiene el código de la aplicación.
     *
     * @return código de aplicación
     */
    String getAppCode();

    /**
     * Obtiene el momento del inicio de la aplicación.
     *
     * @return momento en que se arrancó la aplicación
     */
    long getStartUp();
}
