/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.filter;

import java.io.IOException;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.web.multipart.MaxUploadSizeExceededException;
import org.springframework.web.multipart.support.MultipartFilter;

import es.xunta.amtega.transversal.archam.core.web.util.HttpUtils;

/**
 * Gestiona los errores de subida de ficheros que superan el límite definido
 * en el parámetro de configuración 'multipart.max.upload.size'.
 *
 * En caso de producirse un error de este tipo el filtro de upload de
 * ficheros detiene la ejecución de la operación por lo que es necesario
 * realizar una redirección a otra página.
 *
 * Por defecto redirigimos a la misma URL por método GET añadiendo el
 * parámetro "upload_error". Si empleamos la definición de misma URL para
 * consulta (GET) y guardado (POST) este comportamiento debe ser correcto
 * para gestionar los errores de subida de ficheros comprobando si existe el
 * parámetro en la request para mostrar un error al usuario.
 */
public class ExceptionAwareMultipartFilter extends MultipartFilter {

    private static final Logger LOGGER = LogManager.getLogger(ExceptionAwareMultipartFilter.class);
    
    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain)
            throws ServletException, IOException {
        try {
            super.doFilterInternal(request, response, filterChain);
        } catch (MaxUploadSizeExceededException e) {
            LOGGER.info("Error de validación en el tamaño del fichero", e);
            //Capturamos error en la ejecución normal y redirigimos
            String redirect = HttpUtils.buildRequestUrl(request, "upload_error=MaxUploadSizeExceededException");
            response.sendRedirect(redirect);
        }
    }
}
