/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.filter;

import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.AND;
import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.EQ;
import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.Q_MARK;
import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.REFERER;
import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.REFERER_PARAM;
import static es.xunta.amtega.transversal.archam.core.web.util.HttpUtils.REFERER_PARAM_NAME;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletResponseWrapper;

import es.xunta.amtega.transversal.archam.core.web.util.HttpUtils;

/**
 * Gestiona el valor del parámetro de referer manteniendo información de la
 * página anterior para poder volver a esta creando un enlace en la vista. El
 * valor del referer se publica como un atributo en la request para poder
 * recuperarla en la capa de vista o control.
 *
 */
public class RefererManagerFilter implements Filter {
    
    @Override
    public void destroy() {
        // Nothing to do
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
            throws IOException, ServletException {

        HttpServletRequest servletRequest = (HttpServletRequest) request;
        HttpServletResponse servletResponse = (HttpServletResponse) response;

        final String referer = HttpUtils.getReferer(servletRequest);
        if (request.getAttribute(REFERER) == null) {
            // Añade el atributo referer a la request
            request.setAttribute(REFERER, referer);
            request.setAttribute(REFERER_PARAM_NAME, REFERER_PARAM);
            request.setAttribute(REFERER_PARAM, HttpUtils.encode(referer));
        }

        chain.doFilter(request, new GenericResponseWrapper(servletResponse, referer));
    }

    @Override
    public void init(FilterConfig arg0) throws ServletException {
        // Nothing to do
    }

    /**
     * Wrapper para la respuesta que permite modificar el valor de la cabecera
     * Location y añadir el parámetro referer.
     */
    public class GenericResponseWrapper extends HttpServletResponseWrapper {

        private final String referer;

        /**
         * Constructor del wrapper para la respuesta.
         *
         * @param response la respuesta HTTP.
         * @param referer el referer a incluir en la respuesta.
         */
        public GenericResponseWrapper(final HttpServletResponse response, String referer) {
            super(response);
            this.referer = referer;
        }

        @Override
        public void sendRedirect(String location) throws IOException {
            String newLocation = composeNewLocation(location, HttpUtils.encode(referer));
            super.sendRedirect(newLocation);
        }

        private String composeNewLocation(String location, String referer) {
            if (location != null && !location.contains(REFERER_PARAM.concat(EQ))) {
                StringBuilder builder = new StringBuilder(location);
                builder.append(location.contains(Q_MARK) ? AND : Q_MARK);
                builder.append(REFERER_PARAM);
                builder.append(EQ);
                builder.append(referer);
    
                return builder.toString();
            }
    
            return location;
        }
    }

}
