/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.logging;

import javax.servlet.http.HttpServletRequest;

import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import es.xunta.amtega.transversal.configuration.environment.EnvironmentVariables;
import es.xunta.amtega.transversal.logging.AuditingDataProvider;
import es.xunta.amtega.transversal.utils.BaseUtils;
import java.security.Principal;

/**
 * <code>AuditingDataProviderImpl</code> es la clase que implementa el proveedor
 * de datos de auditoría.
 */
public class RequestContextAuditingDataProvider implements AuditingDataProvider {

    private static final long serialVersionUID = -845960650772928697L;
    private static final String NA = "NA";
    private final String servidor;

    /**
     * Constructor único.
     * <p>
     * Establece el nombre del servidor de la aplicación.
     */
    public RequestContextAuditingDataProvider() {
        this.servidor = EnvironmentVariables.getServerName();
    }

    /**
     * Obtiene la dirección IP de la solicitud recibida.
     *
     * @return la dirección IP de origen de la petición http. En caso de que no
     * consiga determinarla devolverá la de la última máquina por la que pasó.
     */
    @Override
    public String getIp() {
        // Obtenemos Request actual con utilidades de Spring Framework
        ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (sra == null) {
            return NA;
        }

        HttpServletRequest request = sra.getRequest();
        // IP proporcionada por proxy
        String ipOriginal = request.getHeader("X-Forwarded-For");
        return ipOriginal == null ? request.getRemoteAddr() : ipOriginal;
    }

    /**
     * Obtiene el nombre de usuario logueado en la aplicación.
     *
     * @return el nombre del usuario o el valor <code>NA</code> en caso de que
     * este no esté disponible.
     */
    @Override
    public String getUsuario() {
        final ServletRequestAttributes sra = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if(sra == null) {
            return NA;
        }

        final Principal principal = sra.getRequest().getUserPrincipal();

        return principal == null ? NA : principal.getName();
    }

    /**
     * Devuelve el nombre del host local.
     *
     * @return el nombre del host local o el valor <code>NA</code> en caso de
     * que este no esté disponible.
     */
    @Override
    public String getServidor() {
        return this.servidor;
    }

    /**
     * Devuelve la versión de la aplicación.
     *
     * @return la versión o el valor <code>NA</code> en caso de que este no esté
     * disponible.
     */
    @Override
    public String getVersion() {
        return BaseUtils.Configuration.getProperty("app.version", NA);
    }

}
