/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.mvc;

/**
 * Mensaje que se añade al contexto. Se le aplica un estilo dependiendo del
 * tipo de mensaje.
 */
public class Message implements java.io.Serializable {

    private static final long serialVersionUID = 1L;

    public static final String MESSAGE_ATTRIBUTE = "message";

    /**
     * Conjunto de tipos de mensaje.
     * <p>
     * Incluye los siguientes:
     * <ul>
     * <li>DANGER</li>
     * <li>WARNING</li>
     * <li>INFO</li>
     * <li>SUCCESS</li>
     * </ul>
     */
    public enum Type {
        DANGER, WARNING, INFO, SUCCESS;
    }

    private final String message;
    private final Type type;
    private final transient Object[] args;

    /**
     * Constructor de la clase.
     *
     * @param message el texto del mensaje.
     * @param type el tipo de mensaje.
     */
    public Message(String message, Type type) {
        this.message = message;
        this.type = type;
        this.args = null;
    }

    /**
     * Constructor con argumentos.
     *
     * @param message el texto del mensaje.
     * @param type el tipo de mensaje.
     * @param args la lista de parámetros.
     */
    public Message(String message, Type type, Object... args) {
        this.message = message;
        this.type = type;
        this.args = args;
    }

    public String getMessage() {
        return message;
    }

    public Type getType() {
        return type;
    }

    public Object[] getArgs() {
        return args;
    }
}
