/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.filter;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;

import java.io.IOException;

import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.junit.Test;
import org.springframework.mock.web.MockFilterChain;
import org.springframework.mock.web.MockHttpServletRequest;

import es.xunta.amtega.transversal.archam.core.web.context.ExecutionContext;

/**
 * Tests unitarios para el filtro ExecutionContextFilter 
 */
public class ExecutionContextFilterTest {
    
    @Test
    public void doFilterShouldAddNewExecutionContextToRequest() throws ServletException, IOException {
        //given: Declaramos el filtro y la configuración
        ExecutionContextFilter filter = new ExecutionContextFilter();
        FilterConfig config = mock(FilterConfig.class);
        MockFilterChain mockChain = new MockFilterChain();
        HttpServletRequest request = new MockHttpServletRequest();
        HttpServletResponse response = mock(HttpServletResponse.class);
        //llamamos a init
        filter.init(config);
        
        //when: llamamos al doFilter
        filter.doFilter(request, response, mockChain);
        
        //then: validamos que se añade el executionContext
        ExecutionContext executionContext = (ExecutionContext) request.getAttribute("executionContext");
        assertThat(executionContext, is(notNullValue()));
        assertThat(executionContext.getVersion(), is("1.2.3-SNAPSHOT"));
        assertThat(executionContext.getArchetypeId(), is("my-archetype-id"));
        assertThat(executionContext.getArchetypeVersion(), is("my-archetype-version"));
        assertThat(executionContext.getEnvironment(), is("test")); // Definido en amtega-common-test
        assertThat(executionContext.getServerName(), is("jUnitTests")); // Definido en amtega-common-test
        assertThat(executionContext.getAppCode(), is("testapp"));
        assertThat(executionContext.getStartUp(), is(notNullValue()));
    }
    
    @Test
    public void testDestroy() {
        //given: Declaramos el filtro
        ExecutionContextFilter filter = new ExecutionContextFilter();
        
        //when: Llamamos al método destroy
        filter.destroy();
        
        //then: nada que validar
    }
}
