/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.logging;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import es.xunta.amtega.transversal.logging.AuditingDataProvider;
import es.xunta.amtega.transversal.utils.BaseUtils;

/**
 * Tests unitarios de la clase AuditingDataProviderImpl
 */
public class RequestContextAuditingDataProviderTest {

    private AuditingDataProvider auditingData;

    private static final String NA = "NA";
    
    @Before
    public void setup() {
        auditingData = new RequestContextAuditingDataProvider();
    }

    @Test
    public void getIpWithNullServletRequestAttributesShouldReturnNaIp() {
        //given: inicializamos el valor de los atributos de la request a null
        RequestContextHolder.setRequestAttributes(null);
        // when: obtenemos la IP
        String ip = auditingData.getIp();
        // then: el método debe devolver la IP
        this.assertValue(NA, ip);
    }
    
    @Test
    public void getIpWithoutHeaderServletRequestAttributesShouldReturnRemoteAddr() {
        //given: inicializamos los atributos de la request
        MockHttpServletRequest request = new MockHttpServletRequest();
        RequestContextHolder.setRequestAttributes(new ServletRequestAttributes(request));
        // when: obtenemos la IP
        String ip = auditingData.getIp();
        // then: el método debe devolver la IP
        this.assertValue(request.getRemoteAddr(), ip);
    }
    
    @Test
    public void getIpWithHeaderServletRequestAttributesShouldReturnRemoteAddr() {
        //given: inicializamos los atributos de la request
        MockHttpServletRequest request = new MockHttpServletRequest();
        String headerIp = BaseUtils.Configuration.getProperty("test.ip");
        request.addHeader("X-Forwarded-For", headerIp);
        RequestContextHolder.setRequestAttributes(new ServletRequestAttributes(request));
        // when: obtenemos la IP
        String ip = auditingData.getIp();
        // then: el método debe devolver la IP
        this.assertValue(headerIp, ip);
    }
    
    @Test
    public void getUsuarioWithoutRequestAttributesShouldReturnUsuarioNA() {
        //given: seteamos el contexto de security a null
        RequestContextHolder.setRequestAttributes(null);
        // when: obtenemos el usuario
        String usuario = auditingData.getUsuario();
        // then: el método debe devolver el usuario
        this.assertValue(NA, usuario);
    }

    @Test
    public void getUsuarioWithoutUsuarioShouldReturnUsuarioNA() {
        //given: seteamos los RequestAttributes en el RequestContextHolder
        MockHttpServletRequest request = new MockHttpServletRequest();
        RequestContextHolder.setRequestAttributes(new ServletRequestAttributes(request));
        // when: obtenemos el usuario
        String usuario = auditingData.getUsuario();
        // then: el método debe devolver el usuario
        this.assertValue(NA, usuario);
    }
    
    @Test
    public void getUsuarioWithUsuarioShouldReturnUsuarioNA() {
        //given: seteamos el usuario en RequestContextHolder
        Authentication authentication = new UsernamePasswordAuthenticationToken("user", "pass", null);
        MockHttpServletRequest request = new MockHttpServletRequest();
        request.setUserPrincipal(authentication);
        RequestContextHolder.setRequestAttributes(new ServletRequestAttributes(request));
        // when: obtenemos el usuario
        String usuario = auditingData.getUsuario();
        // then: el método debe devolver el usuario
        this.assertValue(authentication.getName(), usuario);
    }

    @Test
    public void getUsuarioShouldReturnServidor() {
        // when: obtenemos el nombre del servidor
        String servidor = auditingData.getServidor();
        // then: el método debe devolver el nombre del servidor
        Assert.assertTrue("Se esperaba el nombre del servidor", servidor != null);
    }

    @Test
    public void getUsuarioShouldReturnVersion() {
        // when: obtenemos la versión
        String version = auditingData.getVersion();
        // then: el método debe devolver la versión
        Assert.assertTrue("Se esperaba la versión", version != null);
    }
    
    private void assertValue(String expected, String actual) {
        Assert.assertTrue("Se esperaba un valor", actual != null);
        Assert.assertEquals("Valor incorrecto", expected, actual);
    }

}
