/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.mvc;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.web.servlet.support.RequestDataValueProcessor;

import es.xunta.amtega.transversal.archam.core.web.mvc.ChainedRequestDataValueProcessor;
import es.xunta.amtega.transversal.archam.core.web.mvc.ConversationIdRequestProcessor;
import es.xunta.amtega.transversal.archam.core.web.mvc.ConversationalSessionAttributeStore;

public class ChainedRequestDataValueProcessorTest {
    
    private static final String TEST_ACTION = "action";
    private static final String TEST_HTTP_METHOD = "httpMethod";
    private static final String TEST_URL = "url";
    private static final String TEST_NAME = "name";
    private static final String TEST_VALUE = "value";
    private static final String TEST_TYPE = "type";
    private static final String TEST_CID = "cid";
    private static final String ACTION_ERROR = "El parámetro action no es el esperado";
    private static final String VALUE_ERROR = "El parámetro value no es el esperado";
    private static final String URL_ERROR = "El parámetro url no es el esperado";

    @Test
    public void addProccessor() {
        //given: declaramos un ChainedRequestDataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        
        //when: Añadimos el processor
        dataValueProcessor.add(processor);
        
        //then: validar que se ha añadido
    }
    
    @Test
    public void setProcessors() {
        //given: declaramos un ChainedRequestDataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        Set<RequestDataValueProcessor> processors = new HashSet<>();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        processors.add(processor);
        //when: establecemos el array de procesadores
        dataValueProcessor.setProcessors(processors);
        //then: validar que se ha añadido
    }
    
    @Test
    public void processActionWithEmptyProcessorsShouldReturnAction() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la acción
        String result = dataValueProcessor.processAction(request, TEST_ACTION, TEST_HTTP_METHOD);
        //then: validamos el resultado
        Assert.assertEquals(ACTION_ERROR, TEST_ACTION, result);
    }
    
    @Test
    public void processActionWithProcessorsShouldReturnSameAction() {
        //given: declaramos el dataValueProcessor con procesadores
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la acción
        String result = dataValueProcessor.processAction(request, TEST_ACTION, TEST_HTTP_METHOD);
        //then: validamos el resultado
        Assert.assertEquals(ACTION_ERROR, TEST_ACTION, result);
    }
    
    @Test
    public void processActionWithTestProcessorShouldReturnProcessorAction() {
        //given: declaramos el dataValueProcessor con procesadores
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        CustomRequestDataValueProcessorTest processor = new CustomRequestDataValueProcessorTest();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la acción
        String result = dataValueProcessor.processAction(request, TEST_ACTION, TEST_HTTP_METHOD);
        //then: validamos el resultado
        Assert.assertNotEquals(ACTION_ERROR, result, TEST_ACTION);
        Assert.assertEquals(ACTION_ERROR, CustomRequestDataValueProcessorTest.ACTION, result);
    }    
    
    @Test
    public void processFormFieldValueWithEmptyProcessorsShouldReturnValue() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        String name = "name";
        String value = "value";
        String type = "type";
        //when: procesamos la acción
        String result = dataValueProcessor.processFormFieldValue(request, name, value, type);
        //then: validamos el resultado
        Assert.assertEquals(VALUE_ERROR, result, value);
    }
    
    @Test
    public void processFormFieldValueWithProcessorsShouldReturnSameValue() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la acción
        String result = dataValueProcessor.processFormFieldValue(request, TEST_NAME, TEST_VALUE, TEST_TYPE);
        //then: validamos el resultado
        Assert.assertEquals(VALUE_ERROR, TEST_VALUE, result);
    }
    
    @Test
    public void processFormFieldValueWithTestProcessorsShouldReturnProcessorValue() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        CustomRequestDataValueProcessorTest processor = new CustomRequestDataValueProcessorTest();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la acción
        String result = dataValueProcessor.processFormFieldValue(request, TEST_NAME, TEST_VALUE, TEST_TYPE);
        //then: validamos el resultado
        Assert.assertNotEquals(VALUE_ERROR, result, TEST_VALUE);
        Assert.assertEquals(VALUE_ERROR, CustomRequestDataValueProcessorTest.FORM_FIELD_VALUE, result);
    }
    
    @Test
    public void getExtraHiddenFieldsWithEmptyProcessorsShouldReturnEmptyParams() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: recuperamos los campos ocultos
        Map<String, String> result = dataValueProcessor.getExtraHiddenFields(request);
        //then: validamos que el resultado está vacío
        Assert.assertTrue("El map de parámetros ocultos no está vacío", result.isEmpty());
    }
    
    @Test
    public void getExtraHiddenFieldsWithProcessorsShouldReturnRequestParams() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        request.setAttribute(ConversationalSessionAttributeStore.CID_FIELD, TEST_CID);
        //when: recuperamos los campos ocultos
        Map<String, String> result = dataValueProcessor.getExtraHiddenFields(request);
        //then: validamos que el resultado
        Assert.assertFalse("El map de parámetros ocultos está vacío", result.isEmpty());
        Assert.assertEquals("El parámetro no tiene el valor esperado", TEST_CID, result.get(ConversationalSessionAttributeStore.CID_FIELD));
    }
    
    @Test
    public void processUrlWithEmptyProcessorsShouldReturnSameUrl() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la url
        String result = dataValueProcessor.processUrl(request, TEST_URL);
        //then: validamos el resultado
        Assert.assertEquals(URL_ERROR, TEST_URL, result);
    }
    
    @Test
    public void processUrlWithProcessorsShouldReturnSameUrl() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la url
        String result = dataValueProcessor.processUrl(request, TEST_URL);
        //then: validamos el resultado
        Assert.assertEquals(URL_ERROR, TEST_URL, result);
    }
    
    @Test
    public void processUrlWhitTestProcessorsShouldReturnProcessorUrl() {
        //given: declaramos el dataValueProcessor
        ChainedRequestDataValueProcessor dataValueProcessor = new ChainedRequestDataValueProcessor();
        CustomRequestDataValueProcessorTest processor = new CustomRequestDataValueProcessorTest();
        dataValueProcessor.add(processor);
        MockHttpServletRequest request = new MockHttpServletRequest();
        //when: procesamos la url
        String result = dataValueProcessor.processUrl(request, TEST_URL);
        //then: validamos el resultado
        Assert.assertNotEquals(URL_ERROR, result, TEST_URL);
        Assert.assertEquals(URL_ERROR, CustomRequestDataValueProcessorTest.URL, result);
    }
}
