/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.mvc;

import java.util.Map;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.mock.web.MockHttpServletRequest;

import es.xunta.amtega.transversal.archam.core.web.mvc.ConversationIdRequestProcessor;
import es.xunta.amtega.transversal.archam.core.web.mvc.ConversationalSessionAttributeStore;

/**
 * Tests unitarios de la clase ConversationIdRequestProcessor 
 */
public class ConversationIdRequestProcessorTest {

    @Test
    public void processActionShouldReturnAction() {
        //given: Inicializamos el processor y la action
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        String action = "action";
        MockHttpServletRequest request = new MockHttpServletRequest();
        String httpMethod = "GET";
        
        //when: llamamos al método processAction
        String result = processor.processAction(request, action, httpMethod);
        
        Assert.assertEquals("El parámetro action no es el esperado", result,  action);
    }
    
    @Test
    public void processFormFieldValueShouldReturnValue() {
        //given: Inicializamos el processor
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        String name = "name";
        String value = "value";
        String type = "type";
        
        //when: llamamos al método processAction
        String result = processor.processFormFieldValue(request, name, value, type);
        
        Assert.assertEquals("El parámetro value no es el esperado", result,  value);
    }
    
    @Test
    public void processUrlShouldReturnUrl() {
        //given: Inicializamos el processor
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        String url = "url";
        
        //when: llamamos al método processAction
        String result = processor.processUrl(request, url);
        
        Assert.assertEquals("El parámetro url no es el esperado", result,  url);
    }    
    
    @Test
    public void getExtraHiddenFieldsWitoutCidShouldReturnEmptyParams() {
        //given: declaramos el processor y la request
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        
        //when: añadimos los parámetros extra ocultos
        Map<String, String> params = processor.getExtraHiddenFields(request);
        
        //then: validamos que los parámetros están vacíos
        Assert.assertTrue("Los parámetros recuperados no están vacíos", params.isEmpty());
    }
    
    @Test
    public void getExtraHiddenFieldsWithCidShouldReturnCidParams() {
        //given: declaramos el processor y la request
        ConversationIdRequestProcessor processor = new ConversationIdRequestProcessor();
        MockHttpServletRequest request = new MockHttpServletRequest();
        String cid = "cid-value";
        request.setAttribute(ConversationalSessionAttributeStore.CID_FIELD, cid);
        
        //when: añadimos los parámetros extra ocultos
        Map<String, String> params = processor.getExtraHiddenFields(request);
        
        //then: validamos que se ha recuperado
        Assert.assertFalse("El parámetro se ha recuperado de la request", params.isEmpty());
        Assert.assertTrue("El parámetro no se ha añadido a los parámetros ocultos correctamente", params.containsKey(ConversationalSessionAttributeStore.CID_FIELD));
        Assert.assertEquals("El valor del parámetro cid no es válido", cid, params.get(ConversationalSessionAttributeStore.CID_FIELD));
    }
}
