/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.mvc;

import static es.xunta.amtega.transversal.archam.core.web.mvc.Message.MESSAGE_ATTRIBUTE;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.ui.ExtendedModelMap;
import org.springframework.web.servlet.mvc.support.RedirectAttributes;
import org.springframework.web.servlet.mvc.support.RedirectAttributesModelMap;

import es.xunta.amtega.transversal.archam.core.web.mvc.Message;
import es.xunta.amtega.transversal.archam.core.web.mvc.MessageHelper;

/**
 * Tests unitarios para la clase de utilidades MessageHelper
 */
public class MessageHelperTest {
    
    private static final String TEST_MESSAGE = "message";
    private static final String TEST_ARG = "arg1";

    @Test
    public void successWithRedirectAttributesShoudAddNewSuccessMessage() {
        //given: declaramos los RedirectAttributes
        RedirectAttributes flashAttributes = new RedirectAttributesModelMap();
        //when: añadimos el mensaje
        MessageHelper.success(flashAttributes, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertFlash(flashAttributes, Message.Type.SUCCESS);
    }
    
    @Test
    public void errorWithRedirectAttributesShoudAddNewErrorMessage() {
        //given: declaramos los RedirectAttributes
        RedirectAttributes flashAttributes = new RedirectAttributesModelMap();
        //when: añadimos el mensaje
        MessageHelper.error(flashAttributes, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertFlash(flashAttributes, Message.Type.DANGER);
    }
    
    @Test
    public void infoWithRedirectAttributesShoudAddNewInfoMessage() {
        //given: declaramos los RedirectAttributes
        RedirectAttributes flashAttributes = new RedirectAttributesModelMap();
        //when: añadimos el mensaje
        MessageHelper.info(flashAttributes, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertFlash(flashAttributes, Message.Type.INFO);
    }
    
    @Test
    public void warningWithRedirectAttributesShoudAddNewWarningMessage() {
        //given: declaramos los RedirectAttributes
        RedirectAttributes flashAttributes = new RedirectAttributesModelMap();
        //when: añadimos el mensaje
        MessageHelper.warning(flashAttributes, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertFlash(flashAttributes, Message.Type.WARNING);
    }
    
    @Test
    public void successWithModelShoudAddNewSuccessMessage() {
        //given: declaramos el model
        ExtendedModelMap model = new ExtendedModelMap();
        //when: añadimos el mensaje
        MessageHelper.success(model, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertMessage(model, Message.Type.SUCCESS);
    }
    
    @Test
    public void errorWithModelShoudAddNewErrorMessage() {
        //given: declaramos el model
        ExtendedModelMap model = new ExtendedModelMap();
        //when: añadimos el mensaje
        MessageHelper.error(model, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertMessage(model, Message.Type.DANGER);
    }
    
    @Test
    public void infoWithModelShoudAddNewInfoMessage() {
        //given: declaramos el model
        ExtendedModelMap model = new ExtendedModelMap();
        //when: añadimos el mensaje
        MessageHelper.info(model, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertMessage(model, Message.Type.INFO);
    }
    
    @Test
    public void warningWithModelShoudAddNewWarningMessage() {
        //given: declaramos el model
        ExtendedModelMap model = new ExtendedModelMap();
        //when: añadimos el mensaje
        MessageHelper.warning(model, TEST_MESSAGE, TEST_ARG);
        //then: validamos el mensaje añadido en los flash attributes
        this.assertMessage(model, Message.Type.WARNING);
    }
    
    
    private void assertFlash(RedirectAttributes flashAttributes, Message.Type type) {
        Message message = (Message) flashAttributes.getFlashAttributes().get(MESSAGE_ATTRIBUTE);
        Assert.assertEquals("El mensaje no es el mismo", TEST_MESSAGE, message.getMessage());
        Assert.assertEquals("El tipo no es el mismo", type, message.getType());
        Assert.assertEquals("El argumento no es el mismo", TEST_ARG, message.getArgs()[0]);
    }
    
    private void assertMessage(ExtendedModelMap model, Message.Type type) {
        Message message = (Message) model.get(MESSAGE_ATTRIBUTE);
        Assert.assertEquals("El mensaje no es el mismo", TEST_MESSAGE, message.getMessage());
        Assert.assertEquals("El tipo no es el mismo", type, message.getType());
        Assert.assertEquals("El argumento no es el mismo", TEST_ARG, message.getArgs()[0]);
    }
    
}
