/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.mvc;

import org.junit.Assert;
import org.junit.Test;

import es.xunta.amtega.transversal.archam.core.web.mvc.Message;

/**
 * Tests unitarios de la clase Message 
 */
public class MessageTest {

    @Test
    public void messageWithMessageAndTypeShouldReturnSameMessageAndType() {
        //given: inicializamos un Message con un mensaje y un tipo
        String msg = "message";
        Message message = new Message(msg, Message.Type.DANGER);
        
        //when: recuperamos el mensaje y el tipo
        String msgResult = message.getMessage();
        Message.Type type = message.getType();
        
        //then: validamos que son los mismos
        Assert.assertEquals("El mensaje no es el mismo", msgResult, msg);
        Assert.assertEquals("El tipo no es el mismo", Message.Type.DANGER, type);
    }
    
    @Test
    public void messageWithMessageAndTypeAndArgsShouldReturnSameMessageAndTypeAndArgs() {
        //given: inicializamos un Message con un mensaje y un tipo
        String msg = "message";
        Object arg1 = new Object();
        Object arg2 = new Object();
        Message message = new Message(msg, Message.Type.DANGER, arg1, arg2);
        
        //when: recuperamos el mensaje y el tipo
        String msgResult = message.getMessage();
        Message.Type typeResult = message.getType();
        Object[] argsResult = message.getArgs();
        
        //then: validamos que son los mismos
        Assert.assertEquals("El mensaje no es el mismo", msgResult, msg);
        Assert.assertEquals("El tipo no es el mismo", Message.Type.DANGER,  typeResult);
        Assert.assertEquals("El argumento no es el mismo", argsResult[0], arg1);
        Assert.assertEquals("El argumento no es el mismo", argsResult[1], arg2);
    }
}
