/* amtega-archam-core-web: Amtega Archetype Core Web
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core-web".
*
* "amtega-archam-core-web" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "APP" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.web.util;

import es.xunta.amtega.transversal.utils.BaseUtils;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import org.junit.Test;
import static org.junit.Assert.*;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.web.multipart.MultipartFile;

/**
 * Tests unitarios de la clase MultipartFileUtils 
 */
public class MultipartFileUtilsTest {
   
    /**
     * Test del método getMimeType.
     * 
     * @throws IOException Excepcion
     */
    @Test
    public void getMimeTypeShouldBeText() throws IOException {
        //given: creamos un fichero de texto, y el tipo mime esperado.
        MultipartFile multipart = getNotEmptyMultipartFile();
        String expResult = "text/plain";
        
        //when: recuperamos el tipo mime del fichero creado
        String result = MultipartFileUtils.getMimeType(multipart);
        
        //then: validamos que resulte el tipo esperado
        assertEquals(expResult, result);

    }

    /**
     * Test del método isAllowedContentType, donde se espera un resultado positivo.
     * 
     * @throws IOException Excepcion en caso de error
     */
    @Test
    public void isAllowedContentTypeShouldBeTrue() throws IOException {
        //given: creamos un fichero de texto, que se supone será un tipo simepre permitido.
        MultipartFile multipart = getNotEmptyMultipartFile();
        boolean expResult = true;
        
        //when: consultamos si el tipo es permitido.
        boolean result = MultipartFileUtils.isAllowedContentType(multipart);

        //then: validamos que resulte que es de tipo permitido
        assertEquals(expResult, result);

    }

    /**
     * Crea un fichero Mock de texto plano no vacio.
     *
     * @return el fichero creado.
     * @throws IOException Excepcion en caso de error
     */
    private MockMultipartFile getNotEmptyMultipartFile() throws IOException {

        File createdFile = new File(BaseUtils.Configuration.getTempPath() + "/foo.txt");
        BufferedWriter writer = new BufferedWriter(new FileWriter(createdFile));
        writer.write("Hello world!");
        writer.close();
        InputStream in = new FileInputStream(createdFile);

        return new MockMultipartFile("file", "foo.txt", "text", in);
    }

}
