/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.data;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.EntityListeners;
import javax.persistence.MappedSuperclass;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.springframework.data.annotation.CreatedBy;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.annotation.LastModifiedBy;
import org.springframework.data.annotation.LastModifiedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

/**
 * <code>EntidadAuditable</code> es la clase abstracta utilizada para efectuar
 * la auditoría de las entidades. Las entidades que requieran de información de
 * auditoría pueden extender esta clase para proporcionar esta funcionalidad.
 */
@MappedSuperclass
@EntityListeners(AuditingEntityListener.class)
public abstract class EntidadAuditable implements Serializable {

    private static final long serialVersionUID = 1L;

    @CreatedBy
    @Column(name = "usuariocreacion", length = 50, nullable = false)
    private String usuarioCreacion;

    @CreatedDate
    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "fechacreacion", nullable = false)
    private Date fechaCreacion;

    @LastModifiedBy
    @Column(name = "usuarioultimamodificacion", length = 50)
    private String usuarioUltimaModificacion;

    @LastModifiedDate
    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "fechaultimamodificacion")
    private Date fechaUltimaModificacion;

    public String getUsuarioCreacion() {
        return usuarioCreacion;
    }

    public void setUsuarioCreacion(String usuarioCreacion) {
        this.usuarioCreacion = usuarioCreacion;
    }

    /**
     * Obtiene la fecha de creación de la entidad.
     * 
     * @return fecha de creación de la entidad
     */
    public Date getFechaCreacion() {
        return (Date) (null == fechaCreacion ? null : fechaCreacion.clone());
    }

    public void setFechaCreacion(Date fechaCreacion) {
        this.fechaCreacion = fechaCreacion;
    }

    public String getUsuarioUltimaModificacion() {
        return usuarioUltimaModificacion;
    }

    public void setUsuarioUltimaModificacion(String usuarioUltimaModificacion) {
        this.usuarioUltimaModificacion = usuarioUltimaModificacion;
    }

    /**
     * Obtiene la fecha de la última modificación de la entidad.
     * 
     * @return fecha en que se modificó la entidad por última vez
     */
    public Date getFechaUltimaModificacion() {
        return (Date) (null == fechaUltimaModificacion ? null : fechaUltimaModificacion.clone());
    }

    public void setFechaUltimaModificacion(Date fechaUltimaModificacion) {
        this.fechaUltimaModificacion = fechaUltimaModificacion;
    }
}
