/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.event;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * Clase genérica para notificación de eventos entre distintas
 * funcionalidades/módulos de la aplicación. Estas notificaciones solo están
 * disponibles en componentes dentro de la misma instancia de aplicación.
 */
public class NotificationEvent extends Event<String> {

    private static final long serialVersionUID = 1L;
    private final Map<String, Object> params;

    /**
     * Constructor de un evento de notificación.
     *
     * @param source objeto implicado en la notificación
     */
    public NotificationEvent(String source) {
        super(source);
        this.params = Collections.emptyMap();
    }

    /**
     * Constructor de un evento de notificación con parámetros.
     * 
     * @param source objeto implicado en la notificación
     * @param params parámetros de la notificación
     */
    public NotificationEvent(String source, Map<String, Object> params) {
        super(source);

        if (params == null) {
            throw new IllegalArgumentException("Se esperaba un parámetro params");
        }
        this.params = Collections.unmodifiableMap(new HashMap<>(params));
    }

    public Map<String, Object> getParams() {
        return params;
    }

}
