/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.exception;

import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * <code>BaseDatosException</code> es la excepción utilizada en caso de error en
 * el acceso a base de datos.
 */
public class BaseDatosException extends InternalErrorException {
    
    private static final long serialVersionUID = 1L;
    private static final String SISTEMA = "BASE_DATOS";
    private static final int CODIGO_ERROR = 2;

    /**
     * Constructor de la clase a partir de un texto para la excepción.
     *
     * @param msg
     *            <code>String</code>el texto vinculado a la excepción.
     */
    public BaseDatosException(String msg) {
        super(SISTEMA, TipoError.BASE_DATOS, Criticidad.ALTO, CODIGO_ERROR, msg);
    }

    /**
     * Constructor de la clase a partir del texto y la causa de la excepción.
     *
     * @param msg
     *            <code>String</code> el texto vinculado a la excepción.
     * @param cause
     *            <code>Throwable</code> la causa de la excepción.
     */
    public BaseDatosException(String msg, Throwable cause) {
        super(SISTEMA, TipoError.BASE_DATOS, Criticidad.ALTO, CODIGO_ERROR, msg, cause);
    }

    /**
     * Constructor de la clase a partir de un código de error, del texto y la
     * causa de la excepción.
     *
     * @param codigoError
     *            <code>int</code> el código de error
     * @param msg
     *            <code>String</code> el texto vinculado a la excepción.
     * @param cause
     *            <code>Throwable</code> la causa de la excepción.
     */
    public BaseDatosException(int codigoError, String msg, Throwable cause) {
        super(SISTEMA, TipoError.BASE_DATOS, Criticidad.ALTO, codigoError, msg, cause);
    }

}
