/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.exception;

import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * <code>ResourceNotFoundException</code> Clase genérica para el registro de
 * excepciones de recursos no encontrados con datos de categorización del error.
 */
public class ResourceNotFoundException extends InternalErrorRuntimeException {
    private static final long serialVersionUID = 1L;
    private static final String SISTEMA = "SERVIDOR";

    /**
     * Constructor de la clase a partir de un texto para la excepción.
     *
     * @param msg
     *            <code>String</code>el texto vinculado a la excepción.
     */
    public ResourceNotFoundException(String msg) {
        super(SISTEMA, TipoError.SISTEMA, Criticidad.AVISO, msg);
    }

    /**
     * Constructor de la clase a partir del texto y la causa de la excepción.
     * 
     * @param msg
     *            <code>String</code> el texto vinculado a la excepción.
     * @param cause
     *            <code>Throwable</code> la causa de la excepción.
     */
    public ResourceNotFoundException(String msg, Throwable cause) {
        super(SISTEMA, TipoError.SISTEMA, Criticidad.AVISO, msg, cause);
    }

    /**
     * Constructor de la clase a partir de la causa de la excepción.
     * 
     * @param cause
     *            <code>Throwable</code> la causa de la excepción.
     */
    public ResourceNotFoundException(Throwable cause) {
        super(SISTEMA, TipoError.SISTEMA, Criticidad.AVISO, cause.getMessage(), cause);
    }

}
