/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.io.exception;

import es.xunta.amtega.transversal.archam.core.exception.InternalErrorRuntimeException;
import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * <code>StorageException</code> es la excepción utilizada en errores
 * relacionados con el almacenamiento de ficheros.
 */
public class FileStorageException extends InternalErrorRuntimeException {

    private static final long serialVersionUID = 1L;

    private static final String SISTEMA = "SISTEMA_FICHEROS";

    private static final int CODIGO_ERROR = 4;

    /**
     * Constructor de la clase a partir del texto y la causa de la excepción.
     *
     * @param msg
     *            el texto vinculado a la excepción.
     * @param cause
     *            la causa de la excepción.
     */
    public FileStorageException(String msg, Throwable cause) {
        super(SISTEMA, TipoError.APLICACION, Criticidad.ALTO, CODIGO_ERROR, msg, cause);
    }

    /**
     * Constructor de la clase a partir de la causa de la excepción.
     * 
     * @param cause
     *            la causa de la excepción.
     */
    public FileStorageException(Throwable cause) {
        super(SISTEMA, TipoError.APLICACION, Criticidad.ALTO, CODIGO_ERROR, cause.getMessage(), cause);
    }
    
    /**
     * Constructor de la clase a partir de la causa de la excepción.
     * 
     * @param msg
     *            información del error.
     */
    public FileStorageException(String msg) {
        super(SISTEMA, TipoError.APLICACION, Criticidad.ALTO, CODIGO_ERROR, msg, null);
    }
}
