/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.archam.core.persistence;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.Expression;
import javax.persistence.criteria.Predicate;

/**
 * <code>SpecificationUtils</code> es la clase de utilidades para especificaciones.
 */
public final class PredicateUtils {
    private static final String PERCENT = "%";

    private PredicateUtils() {
    }

    /**
     * Crea un predicado <code>ilike</code>.
     * 
     * @param builder el constructor para los predicados.
     * @param path el parámetro donde se aplica el predicado.
     * @param value el valor del parámetro de búsqueda.
     * @return el predicado resultante.
     */
    public static Predicate ilike(CriteriaBuilder builder, Expression<String> path, String value){
        String param = percentConcat(value);
        
        return builder.like(builder.lower(path), param.toLowerCase());
    }

    /**
     * Concatena el comodín <code>%</code> a una cadena.
     * 
     * @param param la cadena a concatenar.
     * @return la cadena resultante (ejemplo: <code>%param%</code>).'
     */
    public static String percentConcat(String param) {
        return PERCENT.concat(String.valueOf(param)).concat(PERCENT);
    }
}
