/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.aop;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.aspectj.lang.ProceedingJoinPoint;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests unitarios para el ProfilingAspect
 */
public class ProfilingAspectTest {

    private ProfilingAspect aspect = new ProfilingAspect();
    private ProceedingJoinPoint proceedingJoinPoint;

    @Before
    public void setup() {
        proceedingJoinPoint = mock(ProceedingJoinPoint.class);
    }

    /**
     * Validamos la llamada al método profile
     *
     * @throws Throwable Excepción
     */
    @Test
    public void profile() throws Throwable {
        //given: Declaramos el proceed
        TargetClass proceed = new TargetClass();

        when(proceedingJoinPoint.proceed()).thenReturn(proceed);

        //when: llamamos al método
        Object result = aspect.profile(proceedingJoinPoint);

        //then: validamos que el resultado es el esperado
        Assert.assertEquals(proceed, result);
    }

    public class TargetClass {
        private String test;
        public String getTest() {
            return test;
        }
        public void setTest(String test) {
            this.test = test;
        }
    }
}
