/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.data;

import java.util.Date;

import org.junit.Assert;
import org.junit.Test;

/**
 * Test de la entidad auditable
 */
public class EntidadAuditableTest {

    /**
     * Creamos una clase que extiende de EntidadAuditable También podemos
     * testear la entidad auditable en el modelo Documento
     */
    private class Entidad extends EntidadAuditable {

        private static final long serialVersionUID = 1L;
    }

    /**
     * Validamos el Usuario de creación
     */
    @Test
    public void setUsuarioCreacionShouldReturnSameUsuarioCreacion() {
        // given: usuario de creación de la entidad auditable
        String usuarioCreacion = "user";
        Entidad entidadAuditable = new Entidad();

        // when: indicamos el usuario de creacion
        entidadAuditable.setUsuarioCreacion(usuarioCreacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("El usuario de creación no es el mismo", usuarioCreacion,
                entidadAuditable.getUsuarioCreacion());
    }

    /**
     * Validamos el usuario de última modificación
     */
    @Test
    public void setUsuarioUltimaModificacionShouldReturnSameUsuarioUltimaModificacion() {
        // given: usuario de última modificación de la entidad auditable
        String usuarioUltimaModificacion = "user";
        Entidad entidadAuditable = new Entidad();

        // when: indicamos el usuario de última modificación
        entidadAuditable.setUsuarioUltimaModificacion(usuarioUltimaModificacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("El usuario de última modificación no es el mismo", usuarioUltimaModificacion,
                entidadAuditable.getUsuarioUltimaModificacion());
    }

    /**
     * Validamos la fecha de creación
     */
    @Test
    public void setFechaCreacionShouldReturnSameFechaCreacion() {
        // given: fecha de creación de la entidad auditable
        Date fechaCreacion = new Date();
        Entidad entidadAuditable = new Entidad();

        // when: indicamos la fecha de creación
        entidadAuditable.setFechaCreacion(fechaCreacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("La fecha de creación no es la misma", fechaCreacion, entidadAuditable.getFechaCreacion());
    }

    /**
     * Validamos la fecha de creación a null
     */
    @Test
    public void setFechaCreacionNullShouldReturnNull() {
        // given: usuario de creación de la entidad auditable
        Date fechaCreacion = null;
        Entidad entidadAuditable = new Entidad();

        // when: indicamos la fecha de creación
        entidadAuditable.setFechaCreacion(fechaCreacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("La fecha de creación no es nula", fechaCreacion, entidadAuditable.getFechaCreacion());
    }

    /**
     * Validamos la fecha de última modificación
     */
    @Test
    public void setFechaUltimaModificacionShouldReturnSameFechaUltimaModificacion() {
        // given: fecha de última modificación de la entidad auditable
        Date fechaUltimaModificacion = new Date();
        Entidad entidadAuditable = new Entidad();

        // when: indicamos la fecha de última modificación
        entidadAuditable.setFechaUltimaModificacion(fechaUltimaModificacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("La fecha de última modificación no es la misma", fechaUltimaModificacion,
                entidadAuditable.getFechaUltimaModificacion());
    }

    /**
     * Validamos la fecha de última modificación a null
     */
    @Test
    public void setFechaUltimaModificacionNullShouldReturnNull() {
        // given: usuario de creación de la entidad auditable
        Date fechaUltimaModificacion = null;
        Entidad entidadAuditable = new Entidad();

        // when: indicamos la fecha de última modificación
        entidadAuditable.setFechaUltimaModificacion(fechaUltimaModificacion);

        // then: recuperamos el mismo valor
        Assert.assertEquals("La fecha de última modificación no es nula", fechaUltimaModificacion,
                entidadAuditable.getFechaUltimaModificacion());
    }
}
