/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.data;

import java.util.ArrayList;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;

/**
 * Tests unitarios de la clase SpringSecurityAuditorAwareTest
 */
public class UsernameAuditorAwareTest {

    private UsernameAuditorAware usernameAuditorAware;

    @Before
    public void setup() {
        usernameAuditorAware = new UsernameAuditorAware();
    }

    /**
     * Valida que devuelve gest cuando el usuario en el contexto de spring es
     * null
     */
    @Test
    public void getCurrentAuditorWithNullAuthenticationShouldReturnGuest() {
        //given: establecemos el usuario del contexto de spring security a null
        SecurityContextHolder.getContext().setAuthentication(null);

        //when: obtenemos el nombre del usuario
        String result = usernameAuditorAware.getCurrentAuditor();

        //then: validamos el resultado
        Assert.assertEquals(result, "guest");
    }

    /**
     * Valiad que devuelve en nombre del usuario del contexto de spring si es
     * distinto de null
     */
    @Test
    public void getCurrentAuditorWithNotNullAuthenticationShouldReturnAuthenticationName() {
        //given: establecemos el usuario del contexto de spring security a null
        Authentication authentication = new UsernamePasswordAuthenticationToken("user", "pass", new ArrayList<SimpleGrantedAuthority>());
        SecurityContextHolder.getContext().setAuthentication(authentication);

        //when: obtenemos el nombre del usuario
        String result = usernameAuditorAware.getCurrentAuditor();

        //then: validamos el resultado
        Assert.assertEquals(result, authentication.getName());
    }
}
