/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.event;

import java.util.HashMap;
import java.util.Map;

import org.junit.Assert;
import org.junit.Test;

/**
 * Tests unitarios de la clase <code>NotificationEvent</code>
 */
public class NotificationEventTest {

    private static final String TEXT_SOURCE = "source";
    private static final String TEXT_DISTINTO_SOURCE = "El source no es el mismo";
    private static final String TEXT_DISTINTOS_PARAMS = "Los params no son los mismos";

    @Test
    public void newNotificationEventWithSourceShouldCreateNewNotificationEventWithSameSource() {
        //given:Inicializamos un Source
        String source = TEXT_SOURCE;

        //when: Creamos un evento con el constructor con un Source
        NotificationEvent event = new NotificationEvent(source);

        //then: Validamos el valor del source
        Assert.assertEquals(TEXT_DISTINTO_SOURCE, source, event.getSource());
    }

    @Test
    public void newNotificationEventWithSourceAndParamsShouldCreateNewNotificationEventWithSameSourceAndParams() {
        //given:Inicializamos un Source
        String source = TEXT_SOURCE;
        Map<String, Object> params = new HashMap<>();

        //when: usamos el constructor con source y params
        NotificationEvent event = new NotificationEvent(source, params);

        //then: Validamos el valor del source y params
        Assert.assertEquals(TEXT_DISTINTO_SOURCE, source, event.getSource());
        Assert.assertEquals(TEXT_DISTINTOS_PARAMS, params, event.getParams());
    }

    @Test(expected = IllegalArgumentException.class)
    public void newNotificationEventWithSourceAndNullParamsShouldThrowIllegalArgumentException() {
        //given:Inicializamos un Source
        String source = TEXT_SOURCE;
        Map<String, Object> params = null;

        //when: usamos el constructor con source y params
        NotificationEvent event = new NotificationEvent(source, params);
        
        //then: Error (no debe llegar aquí)
        Assert.assertNotNull(event);
        Assert.fail("No se ha producido la excepción esperada IllegalArgumentException");

    }
}
