/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.exception;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;

import es.xunta.amtega.transversal.archam.core.test.AbstractExceptionTest;
import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * Tests unitarios de la excepción <code>BaseDatosException</code>
 */
public class BaseDatosExceptionTest extends AbstractExceptionTest {

    private static final String SISTEMA = "BASE_DATOS";
    private static final String CODIGO_ERROR = "2";
    private static final String TEXT_MESSAGE = "BaseDatosExceptionTest";

    @Rule
    public ExpectedException thrown = ExpectedException.none();
    
    public BaseDatosExceptionTest() {
        super(SISTEMA, TipoError.BASE_DATOS, Criticidad.ALTO);
    }

    @Test
    public void exceptionWithMsg() throws BaseDatosException {
        //given: declaramos el mensaje
        String msg = TEXT_MESSAGE;
        //then: Validamos los valores esperados
        configureExpectedException(thrown, msg, null, CODIGO_ERROR);
        //when: Lanzamos la excepción
        throw new BaseDatosException(msg);
    }

    @Test
    public void exceptionWithMsgAndCause() throws BaseDatosException {
        //given: declaramos el mensaje y la causa
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable();
        //then: Validamos los valores esperados
        configureExpectedException(thrown, msg, cause, CODIGO_ERROR);
        //when: Lanzamos la excepción
        throw new BaseDatosException(msg, cause);
    }

    @Test
    public void exceptionWithMsgAndCauseAndCodigoError() throws BaseDatosException {
        //given: declaramos el mensaje, la causa y el código de error
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable();
        String customCode = "45";
        //then: Validamos los valores esperados
        configureExpectedException(thrown, msg, cause, customCode);
        //when: Lanzamos la excepción
        throw new BaseDatosException(Integer.parseInt(customCode), msg, cause);
    }
    
}
