/* amtega-archam-core: Amtega Archetype Core
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-archam-core”.
*
* "amtega-archam-core" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-archam-core" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.archam.core.exception;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;

import es.xunta.amtega.transversal.archam.core.test.AbstractExceptionTest;
import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * Tests unitarios para la excepción <code>InternalErrorRuntimeException</code>
 */
public class InternalErrorRuntimeExceptionTest extends AbstractExceptionTest {

    private static final String SISTEMA = "SERVIDOR";
    private static final String CODIGO_ERROR = "1";
    private static final String TEXT_MESSAGE = "InternalErrorRuntimeExceptionTest";
    private static final String OBSERVATIONS = "OBSERVATIONS";

    @Rule
    public ExpectedException thrown = ExpectedException.none();
    
    public InternalErrorRuntimeExceptionTest() {
        super(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO);
    }

    @Test
    public void exception() throws ResourceNotFoundException {
        //given: declaramos el mensaje y la causa
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable(msg);
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, CODIGO_ERROR, msg, OBSERVATIONS, cause);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, cause, CODIGO_ERROR, OBSERVATIONS);
        assertException(exception, CODIGO_ERROR, OBSERVATIONS);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionWithoutCauseAndObservaciones() throws ResourceNotFoundException {
        //given: declaramos el mensaje
        String msg = TEXT_MESSAGE;
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, CODIGO_ERROR, msg);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, null, CODIGO_ERROR, null);
        assertException(exception, CODIGO_ERROR, null);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionIntegerCodigoErrorWithoutCauseAndObservaciones() throws ResourceNotFoundException {
        //given: declaramos el mensaje
        String msg = TEXT_MESSAGE;
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, Integer.parseInt(CODIGO_ERROR), msg);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, null, CODIGO_ERROR, null);
        assertException(exception, CODIGO_ERROR, null);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionWithoutObservaciones() throws ResourceNotFoundException {
        //given: declaramos el mensaje y la causa
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable(msg);
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, CODIGO_ERROR, msg, cause);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, null, CODIGO_ERROR, null);
        assertException(exception, CODIGO_ERROR, null);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionIntegerCodigoErrorWithoutObservaciones() throws ResourceNotFoundException {
        //given: declaramos el mensaje y la causa
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable(msg);
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, Integer.parseInt(CODIGO_ERROR), msg, cause);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, null, CODIGO_ERROR, null);
        assertException(exception, CODIGO_ERROR, null);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionWithoutObservacionesAndCodigoError() throws ResourceNotFoundException {
        //given: declaramos el mensaje y la causa
        String msg = TEXT_MESSAGE;
        Throwable cause = new Throwable(msg);
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, msg, cause);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, cause, null, null);
        assertException(exception, null, null);
        //when: Lanzamos la excepción
        throw exception;
    }

    @Test
    public void exceptionWithoutObservacionesAndCodigoErrorAndCause() throws ResourceNotFoundException {
        //given: declaramos el mensaje
        String msg = TEXT_MESSAGE;
        InternalErrorRuntimeException exception = new InternalErrorRuntimeException(SISTEMA, TipoError.SISTEMA, Criticidad.ALTO, msg);
        //then: Validamos los valores esperados
        configureExpectedException(thrown, null, null, null);
        assertException(exception, null, null);
        //when: Lanzamos la excepción
        throw exception;
    }

}
