package es.xunta.amtega.transversal.archam.core.test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.Matchers.hasProperty;

import org.junit.Assert;
import org.junit.rules.ExpectedException;

import es.xunta.amtega.transversal.logging.AuditableException;
import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.StringPool;
import es.xunta.amtega.transversal.logging.TipoError;

public class AbstractExceptionTest {

    private final String expectedSistema;
    private final TipoError expectedTipoError;
    private final Criticidad expectedCriticidad;

    private static final String PROPERTY_SISTEMA = "sistema";
    private static final String PROPERTY_TIPO_ERROR = "tipoError";
    private static final String PROPERTY_CRITICIDAD = "criticidad";
    private static final String PROPERTY_CODIGO_ERROR = "codigoError";
    private static final String PROPERTY_OBSERVACIONES = "observaciones";
    
    public AbstractExceptionTest(String sistema, TipoError tipoError, Criticidad criticidad) {
        this.expectedSistema = sistema;
        this.expectedTipoError = tipoError;
        this.expectedCriticidad = criticidad;
    }
    
    protected void configureExpectedException(ExpectedException thrown, String msg, Throwable cause, String codErro) {
        this.configureExpectedException(thrown, msg, cause, codErro, null);
    }

    protected void configureExpectedException(ExpectedException thrown, String msg, Throwable cause, String codErro, String observacions) {
        //Validamos existencia valores        
        //Agrupamos los "expect" en este método
        if (msg != null) {
            thrown.expectMessage(msg);
        }

        if (cause != null) {
            thrown.expectCause(is(cause));
        }

        thrown.expect(hasProperty(PROPERTY_SISTEMA));
        thrown.expect(hasProperty(PROPERTY_TIPO_ERROR));
        thrown.expect(hasProperty(PROPERTY_CRITICIDAD));
        thrown.expect(hasProperty(PROPERTY_CODIGO_ERROR));
        thrown.expect(hasProperty(PROPERTY_OBSERVACIONES));

        thrown.expect(hasProperty(PROPERTY_SISTEMA, is(expectedSistema)));
        thrown.expect(hasProperty(PROPERTY_TIPO_ERROR, is(expectedTipoError)));
        thrown.expect(hasProperty(PROPERTY_CRITICIDAD, is(expectedCriticidad)));
        if (codErro != null) {
            thrown.expect(hasProperty(PROPERTY_CODIGO_ERROR, is(codErro)));
        } else {
            thrown.expect(hasProperty(PROPERTY_CODIGO_ERROR, is(StringPool.EMPTY)));
        }
        if (observacions != null) {
            thrown.expect(hasProperty(PROPERTY_OBSERVACIONES, is(observacions)));
        } else {
            thrown.expect(hasProperty(PROPERTY_OBSERVACIONES, is(StringPool.EMPTY)));
        }
    }

    protected void assertException(AuditableException exception, String codErro, String observacions) {
        //Agrupamos los "assert" en este método
        Assert.assertEquals(expectedSistema, exception.getSistema());
        Assert.assertEquals(expectedTipoError, exception.getTipoError());
        Assert.assertEquals(expectedCriticidad, exception.getCriticidad());
        if (codErro != null) {
            Assert.assertEquals(codErro, exception.getCodigoError());
        } else {
            Assert.assertEquals(StringPool.EMPTY, exception.getCodigoError());
        }
        if (observacions != null) {
            Assert.assertEquals(observacions, exception.getObservaciones());
        } else {
            Assert.assertEquals(StringPool.EMPTY, exception.getObservaciones());
        }

        Assert.assertEquals(exception.getMensaje(), ((Throwable) exception).getMessage());

    }
    
}
