/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.plugin;

/**
 * Define las funcionalidades de un origen de datos de configuración de un
 * plugin.
 */
public interface ConfigurationSource {

    /**
     * Indica si existe una clave en la configuración
     *
     * @param key clave del parámetro de configuración.
     * @return true si existe la clave
     */
    boolean containsProperty(String key);

    /**
     * Recupera el valor de configuración para la propiedad indicada.
     *
     * @param key clave de propiedad de configuración
     * @return valor de la propiedad
     */
    String getProperty(String key);

    /**
     * Recupera el valor de configuración para la propiedad indicada.
     *
     * @param key clave de propiedad de configuración
     * @param defaultValue valor por defecto si no se encuentra la propiedad
     * @return valor de la propiedad o valor por defecto
     */
    String getProperty(String key, String defaultValue);

    /**
     * Recupera el valor de configuración para la propiedad indicada.
     *
     * @param <T> variable tipo
     * @param key clave de propiedad de configuración.
     * @param targetType tipo de objeto que representa el valor de la propiedad
     * @return valor de la propiedad en el tipo de dato indicado
     */
    <T> T getProperty(String key, Class<T> targetType);

    /**
     * Recupera el valor de configuración para la propiedad indicada.
     *
     * @param <T> variable tipo
     * @param key clave de propiedad de configuración.
     * @param targetType tipo de objeto que representa el valor de la propiedad
     * @param defaultValue valor por defecto si no se encuentra la propiedad
     * @return valor de la propiedad en el tipo de dato indicado o valor por
     * defecto
     */
    <T> T getProperty(String key, Class<T> targetType, T defaultValue);

}
