/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin;

import java.util.Locale;

/**
 * Interfaz del módulo al que pertenece un plugin
 */
public interface Module {

    /**
     * Recupera el nombre del Namespace en el que se añaden los plugins del
     * módulo
     * 
     * @return Namespace
     */
    String getNamespace();

    /**
     * Recupera el nombre del módulo
     * 
     * @param locale
     *            Idioma de la aplicación
     * @return Nombre del módulo
     */
    String getName(Locale locale);

    /**
     * Recupera la descripción sobre el módulo del plugin
     * 
     * @param locale
     *            Idioma de la aplicación
     * @return Descripción del módulo
     */
    String getDescription(Locale locale);

    /**
     * Recupera el desarrollador del módulo
     * 
     * @param locale
     *            Idioma de la aplicación
     * @return Desarrollador
     */
    String getVendor(Locale locale);

    /**
     * Recupera la versión del módulo
     * 
     * @return Versión
     */
    String getVersion();

    /**
     * Recupera la versión mínima necesaria para la ejecución del plugin
     * 
     * @return Versión mínima del soporte de plugins
     */
    String getMinVersion();
}
