/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin.registry;

import java.util.Collection;
import java.util.List;

import es.xunta.amtega.transversal.plugin.PluginInstance;
import es.xunta.amtega.transversal.plugin.PluginType;

/**
 * Interfaz del Plugin Registry
 */
public interface PluginRegistry {

    /**
     * Añade un plugin al map de plugins del registro
     * 
     * @param plugin
     *            Plugin a añadir
     */
    void add(PluginInstance plugin);

    /**
     * Recupera un plugin por id. Usa el namespace por defecto amtega-plugins
     * 
     * @param id
     *            Id del plugin a recuperar
     * @return Plugin encontrado
     */
    PluginInstance getPluginById(String id);

    /**
     * Recupera un plugin por id y por namespace
     * 
     * @param id
     *            Id del plugin
     * @param namespace
     *            Namespace del módulo del plugin
     * @return Plugin encontrado
     */
    PluginInstance getPluginById(String id, String namespace);

    /**
     * Recupera una colección con los plugins disponibles
     * 
     * @return Colección de plugins
     */
    Collection<PluginInstance> getAvailablePlugins();

    /**
     * Recupera una lista de plugins por tipo
     * 
     * @param type
     *            Tipo de plugin a buscar
     * @return Lista de plugins
     */
    List<PluginInstance> getPluginsByType(Class<? extends PluginType> type);

}
