/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin.type;

import static java.util.ResourceBundle.Control.getNoFallbackControl;

import java.util.Locale;
import java.util.ResourceBundle;
import java.util.ResourceBundle.Control;

import javax.servlet.http.HttpServletRequest;

import es.xunta.amtega.transversal.plugin.Notification;

/**
 * Clase que proporciona funcionalidades comunes para la implementación de los
 * distintos tipos de plugins.
 */
public abstract class AbstractComponent implements Component {

    private static final Control NO_FALLBACK_CONTROL = getNoFallbackControl(ResourceBundle.Control.FORMAT_DEFAULT);
    protected static final int DEFAULT_SORT = 0;
    protected static final String EMPTY = "";
    private static final String DEFAULT_BUNDLE_NAME = "i18n/Messages";
    private final String textKey;
    private final String titleKey;
    private String bundleName = DEFAULT_BUNDLE_NAME;

    public AbstractComponent(String textKey, String titleKey) {
        this.textKey = textKey;
        this.titleKey = titleKey;
    }

    public void setBundleName(String bundleName) {
        this.bundleName = bundleName;
    }

    @Override
    public String getId() {
        // El atributo id en HTML es opcional
        return null;
    }

    @Override
    public String getClassName() {
        return EMPTY;
    }

    @Override
    public String getText(Locale locale) {
        return getMessage(textKey, locale);
    }

    public boolean hasText() {
        return textKey != null;
    }

    @Override
    public String getTitle(Locale locale) {
        return getMessage(titleKey, locale);
    }

    public boolean hasTitle() {
        return titleKey != null;
    }

    @Override
    public boolean isVisible(HttpServletRequest request) {
        return true;
    }

    @Override
    public int getSort() {
        return DEFAULT_SORT;
    }

    @Override
    public Integer getTabIndex() {
        // Atributo tabindex es opcional en HTML
        return null;
    }

    @Override
    public Notification getNotification(HttpServletRequest request) {
        return null;
    }

    protected String getMessage(String key, Locale locale) {
        if (key == null) {
            return EMPTY;
        }

        ResourceBundle bundle = ResourceBundle.getBundle(bundleName, locale, NO_FALLBACK_CONTROL);
        if (bundle.containsKey(key)) {
            return bundle.getString(key);
        }

        return key;
    }

}
