/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.plugin.type;

import java.util.Collections;
import java.util.List;
import java.util.Locale;

/**
 * Implementa las características básicas de un plugin de tipo SidebarMenuEntry.
 * Permite reducir el número de código necesario para crear un plugin de este
 * tipo ya que proporciona el comportamiento por defecto, solo es necesario
 * sobreescribir los métodos para los que queramos cambiar el comportamiento por
 * defecto.
 */
public abstract class AbstractSidebarMenuEntry extends AbstractLinkComponent implements SidebarMenuEntry {

    // El atributo id es obligatorio en los enlaces de menú lateral ya que
    // indican el menú seleccionado
    private final String id;

    public AbstractSidebarMenuEntry(String id, String textKey, String titleKey, String path) {
        super(textKey, titleKey, path);
        this.id = id;
    }

    @Override
    public String getId() {
        return id;
    }

    @Override
    public List<SidebarMenuEntry> getEntries(Locale locale) {
        return Collections.emptyList();
    }

}
