/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin.type;

import java.util.Locale;

import javax.servlet.http.HttpServletRequest;

import es.xunta.amtega.transversal.plugin.Notification;

public interface Component {

    /**
     * Identificador del componente, se corresponde con el atributo id de HTML,
     * debe ser único en la página
     * 
     * @return Opción activa
     */
    String getId();

    /**
     * Valor del atributo "class" de HTML
     * 
     * @return valor del atributo class
     */
    String getClassName();

    /**
     * Valor del atributo tabindex de HTML
     * 
     * @return valor de tabindex o null si el componente no tiene este atributo
     */
    Integer getTabIndex();

    /**
     * Texto del componente
     * 
     * @param locale
     *            Idioma de la aplicación
     * @return valor del texto en el idioma indicado
     */
    String getText(Locale locale);

    /**
     * Título de ayuda del componente
     * 
     * @param locale
     *            Idioma de la aplicación
     * @return Título
     */
    String getTitle(Locale locale);

    /**
     * Recupera información de notificación que acompaña a este componente
     * 
     * @param request
     *            petición HTTP actual
     * @return notificación o null si no tiene información de notificación
     */
    Notification getNotification(HttpServletRequest request);

    /**
     * Indica si el componente es visible en la interfaz de usuario.
     * 
     * @param request
     *            petición HTTP actual
     * @return true si el plugin es visible
     */
    boolean isVisible(HttpServletRequest request);

    /**
     * Devuelve el valor de ordenación de una instancia de este componente
     * 
     * @return ordenación del componente, un valor inferior se muestra primero
     */
    int getSort();

}
