/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin.type;

import javax.servlet.http.HttpServletRequest;

import es.xunta.amtega.transversal.plugin.Notification;

/**
 * Clase de utilidad que permite crear componentes de tipo entrada de menú
 */
public final class NavbarMenuEntryBuilder {

    private String textKey;
    private String titleKey;
    private String path;
    private String className;
    private String id;
    private boolean isDivider;
    private Notification notification;
    
    public NavbarMenuEntryBuilder divider(){
        this.isDivider = true;
        return this;
    }
    
    public NavbarMenuEntryBuilder setText(String textKey){
        this.textKey = textKey;
        return this;
    }
    
    public NavbarMenuEntryBuilder setTitle(String titleKey){
        this.titleKey = titleKey;
        return this;
    }
    
    public NavbarMenuEntryBuilder setPath(String path){
        this.path = path;
        return this;
    }
    
    public NavbarMenuEntryBuilder setClassName(String className){
        this.className = className;
        return this;
    }
    
    public NavbarMenuEntryBuilder setId(String id){
        this.id = id;
        return this;
    }
    
    public NavbarMenuEntryBuilder setNotification(Notification notification){
        this.notification = notification;
        return this;
    }
    
    public NavbarMenuEntry build(){
        if( isDivider ){
            return new DividerNavbarMenuEntry();
        }
        
        return new DefaultNavbarMenuEntry(textKey, titleKey, path, id, className, notification);
    }
    
    private class DefaultNavbarMenuEntry extends AbstractNavbarMenuEntry{

        private final String className;
        private final String id;
        private final Notification notification;
        
        public DefaultNavbarMenuEntry(String textKey, String titleKey, String path,String id, String className, Notification notification) {
            super(textKey, titleKey, path);
            this.id = id;
            this.className = className;
            this.notification = notification;
        }
        
        @Override
        public String getId() {
            return id;
        }
        
        @Override
        public String getClassName() {
            return className;
        }
        
        @Override
        public Notification getNotification(HttpServletRequest request) {
            return notification;
        }
        
    }

    private class DividerNavbarMenuEntry extends AbstractNavbarMenuEntry {

        private static final String DIVIDER = "divider";
        
        public DividerNavbarMenuEntry() {
            super(null, null, null);
        }

        @Override
        public String getClassName() {
            return DIVIDER;
        }

    }
}