/* amtega-base-plugin-api: Modulo API del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
 */
package es.xunta.amtega.transversal.plugin.type;

import javax.servlet.http.HttpServletRequest;

import es.xunta.amtega.transversal.plugin.Notification;

/**
 * Clase de utilidad que permite crear componentes de entrada de menú principal
 */
public final class SidebarMenuEntryBuilder {

    private final String id;
    private final String textKey;
    private String titleKey;
    private String path;
    private Notification notification;

    public SidebarMenuEntryBuilder(String id, String textKey) {
        this.id = id;
        this.textKey = textKey;
    }

    public SidebarMenuEntryBuilder setTitleKey(String titleKey) {
        this.titleKey = titleKey;
        return this;
    }

    public SidebarMenuEntryBuilder setPath(String path) {
        this.path = path;
        return this;
    }

    public SidebarMenuEntryBuilder setNotification(Notification notification) {
        this.notification = notification;
        return this;
    }

    /**
     * Crea una instancia de componente de entrada de menú
     *
     * @return la entrada de menú
     */
    public SidebarMenuEntry build() {
        return new DefaultSidebarMenuEntry(id, textKey, titleKey, path, notification);
    }

    private class DefaultSidebarMenuEntry extends AbstractSidebarMenuEntry {

        private final Notification notification;

        public DefaultSidebarMenuEntry(String id, String textKey, String titleKey, String path, Notification notification) {
            super(id, textKey, titleKey, path);
            this.notification = notification;
        }

        @Override
        public Notification getNotification(HttpServletRequest request) {
            return notification;
        }

    }
}
