package es.xunta.amtega.transversal.plugin.type;

import static org.junit.Assert.*;

import java.util.Locale;

import org.junit.Test;

public class AbstractComponentTest {
    
    private Locale LOCALE_GL_ES = new Locale("gl", "ES");
    private Locale LOCALE_ES = new Locale("es");
    private Locale LOCALE_ES_ES = new Locale("es", "ES");
    
    private String BUNDLE_1 = "i18n/Messages1";
    private String BUNDLE_2 = "i18n/Messages2";
    
    private String PROPERTY = "clave";

    @Test
    public void shouldUseDefaultBundle() {
        // given
        TestComponent component = new TestComponent(BUNDLE_1);
        // when
        String value = component.getMessage(PROPERTY, LOCALE_GL_ES);
        // then - Usa properties por defecto
        assertEquals("valor gl", value);
    }

    @Test
    public void shouldTranslateLanguage() {
        // given
        TestComponent component = new TestComponent(BUNDLE_1);
        // when
        String value = component.getMessage(PROPERTY, LOCALE_ES);
        // then - Usa properties de idioma -> "_es"
        assertEquals("valor es", value);
    }

    @Test
    public void shouldUseLanguageForFullLocale() {
        // given
        TestComponent component = new TestComponent(BUNDLE_1);
        // when
        String value = component.getMessage(PROPERTY, LOCALE_ES_ES);
        // then - Usa properties de idioma -> "_es"
        assertEquals("valor es", value);
    }

    @Test
    public void shouldUseDefaultForLanguage() {
        // given
        TestComponent component = new TestComponent(BUNDLE_2);
        // when
        String value = component.getMessage(PROPERTY, LOCALE_ES);
        // then - No encuentra properties para idioma sólo (sin región) -> usa default
        assertEquals("default gl", value);
    }

    @Test
    public void shouldUseLocaleForFullLocale() {
        // given
        TestComponent component = new TestComponent(BUNDLE_2);
        // when
        String value = component.getMessage(PROPERTY, LOCALE_ES_ES);
        // then - Usa properties de región -> "_es_ES"
        assertEquals("valor es_ES", value);
    }

    
    
    private class TestComponent extends AbstractComponent {
        public TestComponent(String bundle) {
            super("test", "test");
            this.setBundleName(bundle);
        }
    }

}
