/* amtega-base-plugin-spring-impl: Módulo implementación Spring del proyecto Amtega Plugins
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-base-plugin”.
*
* "amtega-base-plugin" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-base-plugin" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.plugin.registry;

import es.xunta.amtega.transversal.plugin.Module;
import es.xunta.amtega.transversal.plugin.PluginInstance;
import es.xunta.amtega.transversal.plugin.PluginType;

/**
 * Implementación de la interfaz PluginInstance
 */
class PluginInstanceImpl implements PluginInstance {
    
    private final String id;
    private final Module module;
    private final Class<? extends PluginType> type;
    private final PluginType instance;
    
    /**
     * Constructor
     * @param id Id del plugin
     * @param module Módulo
     * @param type Tipo
     * @param instance Instancia
     */
    private PluginInstanceImpl(String id, Module module, Class<? extends PluginType> type, PluginType instance) {
        this.id = id;
        this.module = module;
        this.type = type;
        this.instance = instance;
    }
    
    /**
     * Valida los parámetros del plugin
     * @param id Id
     * @param module Módulo
     * @param type Tipo
     * @param instance Instancia
     * @return Una nueva instancia
     */
    public static PluginInstanceImpl with(String id, Module module, Class<? extends PluginType> type, PluginType instance){
        if(id==null){
            throw new IllegalArgumentException("No se ha indicado el id del plugin");
        }
        
        if(module==null){
            throw new IllegalArgumentException("No se ha indicado el módulo del plugin");
        }
        
        if(type==null){
            throw new IllegalArgumentException("No se ha indicado el tipo de plugin");
        }
        
        if(instance==null){
            throw new IllegalArgumentException("No se ha indicado la instancia del plugin");
        }
        
        return new PluginInstanceImpl(id, module, type, instance);
    }

    @Override
    public String getId() {
        return id;
    }

    @Override
    public Module getModule() {
        return module;
    }

    @Override
    public Class<? extends PluginType> getType() {
        return type;
    }

    @Override
    public PluginType getInstance() {
        return instance;
    }

    @SuppressWarnings("unchecked")
    @Override
    public <T extends PluginType> T getInstance(Class<T> type) {
        return (T) instance;
    }
    
    @Override
    public String toString() {
        return instance.toString();
    }
    
}
