/* amtega-common-authentication: Amtega Common Authentication
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authentication".
*
* "amtega-common-authentication" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authentication" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authentication;

import java.io.Serializable;

/**
 * Datos de una cuenta de usuario
 */
public interface Account extends Serializable {
    
    /**
     * Obtiene el usuario
     * @return Usuario
     */
    String getUsuario();

    /**
     * Obtiene el nombre
     * @return Nombre
     */
    String getNombre();

    /**
     * Obtiene los apellidos
     * @return Apellidos
     */
    String getApellidos();

    /**
     * Obtiene el correo electrónico
     * @return Correo electrónico
     */
    String getCorreoElectronico();

    /**
     * Obtiene el NIF
     * @return NIF
     */
    String getDni();

    /**
     * Obtiene una propiedad del usuario
     * @param key Clave de la propiedad
     * @return Valor de la propiedad
     */
    Object getProperty(String key);

    /**
     * Obtiene una propiedad del usuario
     * @param <T> Clase de la propiedad
     * @param key Clave de la propiedad
     * @param type Tipo de propiedad
     * @return Valor de la propiedad
     */
    <T> T getProperty(String key, Class<T> type);

}
