/* amtega-common-authentication: Amtega Common Authentication
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authentication".
*
* "amtega-common-authentication" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authentication" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authentication.provider;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.ServiceLoader;

/**
 * Clase encargada de crear la instancia del proveedor de autenticación según la
 * configuración del módulo
 */
public final class AuthenticationProviderRegistry {
    private static final AuthenticationProviderRegistry INSTANCE = new AuthenticationProviderRegistry();
    private final Collection<AuthenticationProvider> providers;

    private AuthenticationProviderRegistry() {
        ServiceLoader<AuthenticationProvider> loader = ServiceLoader.load(AuthenticationProvider.class);

        // Cargamos todos los proveedores definidos como servicio
        // (META-INF/services)
        final List<AuthenticationProvider> availableProviders = new ArrayList<AuthenticationProvider>();
        Iterator<AuthenticationProvider> it = loader.iterator();
        while (it.hasNext()) {
            availableProviders.add((AuthenticationProvider) it.next());
        }

        // Ordenación por prioridad
        Collections.sort(availableProviders, new Comparator<AuthenticationProvider>() {

            @Override
            public int compare(AuthenticationProvider o1, AuthenticationProvider o2) {
                if (o1.getPriority() == o2.getPriority()) {
                    return 0;
                }

                return o1.getPriority() < o2.getPriority() ? -1 : 1;
            }
        });

        providers = Collections.unmodifiableCollection(availableProviders);
    }

    public static AuthenticationProviderRegistry getInstance() {
        return INSTANCE;
    }

    public Collection<AuthenticationProvider> getProviders() {
        return providers;
    }

}
