/* amtega-common-authentication: Amtega Common Authentication
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authentication".
*
* "amtega-common-authentication" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authentication" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authentication.provider.impl;

import java.util.Collections;
import java.util.Map;

import es.xunta.amtega.transversal.authentication.Account;

final class AccountImpl implements Account {
    private static final long serialVersionUID = -1536467600796530284L;
    private Map<String, Object> values;
    private static final String DEFAULT_VALUE = "";
    public static final String USUARIO = "sAMAccountName";
    public static final String NOMBRE = "givenName";
    public static final String APELLIDOS = "sn";
    public static final String EMAIL = "mail";
    public static final String DNI = "employeeID";

    public AccountImpl(Map<String, Object> attrs) {
        this.values = attrs;
    }

    @Override
    public String getUsuario() {
        return getProperty(USUARIO, String.class);
    }

    @Override
    public String getNombre() {
        return getProperty(NOMBRE, String.class);
    }

    @Override
    public String getApellidos() {
        return getProperty(APELLIDOS, String.class);
    }

    @Override
    public String getCorreoElectronico() {
        return getProperty(EMAIL, String.class);
    }

    @Override
    public String getDni() {
        return getProperty(DNI, String.class);
    }

    @SuppressWarnings("unchecked")
    @Override
    public <T> T getProperty(String key, Class<T> type) {
        Object value = values.get(key);
        return (T) ((value == null && type.equals(String.class)) ? DEFAULT_VALUE : value);
    }

    @Override
    public Object getProperty(String key) {
        return getProperty(key, Object.class);
    }

    @Override
    public String toString() {
        return this.values.toString();
    }

    public static Account build(Map<String, Object> attrs) {
        return new AccountImpl(Collections.unmodifiableMap(attrs));
    }

}
