/* amtega-common-authentication: Amtega Common Authentication
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authentication".
*
* "amtega-common-authentication" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authentication" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authentication.provider.impl;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import es.xunta.amtega.transversal.authentication.Account;
import es.xunta.amtega.transversal.authentication.exception.AccountNotFoundException;
import es.xunta.amtega.transversal.authentication.exception.CommunicationException;
import es.xunta.amtega.transversal.authentication.exception.InvalidLoginCredentialsException;
import es.xunta.amtega.transversal.authentication.provider.AuthenticationProvider;

/**
 * Implementación de proveedor de autenticación dummy
 */
public final class DummyAuthenticationProviderImpl implements AuthenticationProvider {
    private boolean active = false;
    private static final int DEFAULT_PRIORITY = 100;

    @Override
    public void login(String username, String password)
            throws InvalidLoginCredentialsException, CommunicationException {
        // El login siempre es correcto
    }

    @Override
    public Account findAccount(String username) throws AccountNotFoundException {
        return createAccount(username);
    }

    @Override
    public void setup(Properties config) {
        active = Boolean.parseBoolean(config.getProperty("authentication.dummy", Boolean.FALSE.toString()));
    }

    @Override
    public List<Account> findAccounts(String username) throws CommunicationException {
        return Collections.singletonList(createAccount(username));
    }

    /**
     * Crea unha conta
     * @param username Nome de usuario
     * @return Conta dummy
     */
    private Account createAccount(String username) {
        final Map<String, Object> attrs = new HashMap<String, Object>();
        attrs.put(AccountImpl.USUARIO, username);
        attrs.put(AccountImpl.NOMBRE, "Usuario");
        attrs.put(AccountImpl.APELLIDOS, "Apellido Apellido");
        attrs.put(AccountImpl.EMAIL, "usuario@email.com");
        attrs.put(AccountImpl.DNI, "00000000A");

        return AccountImpl.build(attrs);
    }

    @Override
    public boolean isActive() {
        return active;
    }

    @Override
    public int getPriority() {
        return DEFAULT_PRIORITY;
    }

    @Override
    public String getIdentifier() {
        return "dummy";
    }

}
