/* amtega-common-authentication: Amtega Common Authentication
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authentication".
*
* "amtega-common-authentication" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authentication" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.test.provider;

import java.util.Collections;
import java.util.List;
import java.util.Properties;

import es.xunta.amtega.transversal.authentication.Account;
import es.xunta.amtega.transversal.authentication.exception.AccountNotFoundException;
import es.xunta.amtega.transversal.authentication.exception.CommunicationException;
import es.xunta.amtega.transversal.authentication.exception.InvalidLoginCredentialsException;
import es.xunta.amtega.transversal.authentication.exception.MultipleAccountsMatchException;
import es.xunta.amtega.transversal.authentication.provider.AuthenticationProvider;

public class TestAuthenticationProvider implements AuthenticationProvider {
    private boolean active;
    private Account account;

    public TestAuthenticationProvider() {
        this.account = new TestAccountImpl();
    }

    @Override
    public String getIdentifier() {
        return "test";
    }

    @Override
    public void login(String username, String password)
            throws InvalidLoginCredentialsException, CommunicationException {
        // nothing to do
    }

    @Override
    public Account findAccount(String username)
            throws AccountNotFoundException, MultipleAccountsMatchException, CommunicationException {
        return this.account;
    }

    @Override
    public List<Account> findAccounts(String query) throws CommunicationException {

        return Collections.singletonList(this.account);
    }

    @Override
    public void setup(Properties config) {
        active = Boolean.parseBoolean(config.getProperty("test.active", Boolean.FALSE.toString()));
    }

    @Override
    public boolean isActive() {
        return active;
    }

    @Override
    public int getPriority() {
        return 0;
    }
    
    
    
    private static class TestAccountImpl implements Account {
        private static final long serialVersionUID = 1L;
        @Override
        public String getUsuario() {
            return "test";
        }
        @Override
        public <T> T getProperty(String key, Class<T> type) {
            return null;
        }
        @Override
        public Object getProperty(String key) {
            return "test";
        }
        @Override
        public String getNombre() {
            return "test";
        }
        @Override
        public String getDni() {
            return "test";
        }
        @Override
        public String getCorreoElectronico() {
            return "test";
        }
        @Override
        public String getApellidos() {
            return "test";
        }
    }

}
