/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization;

/**
 * Proveedor de datos de autorización. Se encarga de realizar las tareas de bajo
 * nivel para consultar la información de autorización disponible para un
 * usuario.
 */
public interface AuthoritiesProvider {

    /**
     * Realiza la consulta de información de autorización disponible para un
     * usuario en un determinado contexto de ejecución
     * 
     * @param subject
     *            identificación de usuario
     * @param context
     *            contexto de ejecución
     * @return información de autorización para el usuario
     */
    Policy getAuthorities(Subject<?> subject, Context context);

    /**
     * El proveedor de datos de autorización determina si puede recuperar la
     * información para el usuario empleando un tipo de dato de identificador
     * (String, Long, etc.)
     * 
     * @param cls
     *            clase que determina el tipo de identificador de usuario
     * @return true si el proveedor soporta el tipo de identificador de usuario
     *         indicado
     */
    boolean supports(Class<?> cls);

    /**
     * Determina la prioridad de este proveedor sobre otros posibles proveedores
     * (menor prioridad se ejecuta primero)
     * 
     * @return prioridad del proveedor
     */
    int getPriority();

}
