/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization;

import java.util.Map;
import java.util.Set;

/**
 * Interfaz que engloba la información de autorización para un usuario
 */
public interface Policy {

    /**
     * Devuelve el conjunto de roles asociados a esta política de autorización
     * 
     * @return conjunto de roles
     */
    Set<String> getRoles();

    /**
     * Devuelve el cojunto de permisos asociados a esta política de autorización
     * 
     * @return conjunto de permisos
     */
    Set<String> getPermissions();

    /**
     * Datos de contexto para la aplicación de los permisos y roles
     * 
     * @return datos adicionales para realizar validaciones propias sobre
     *         permisos y perfiles del usuario, p.ej.: el ámbito de aplicación
     *         de cierto permiso, validez de los permisos, etc.
     */
    Map<String, Object> getContext();

}
