/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization.builder;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.ServiceLoader;

import es.xunta.amtega.transversal.authorization.AuthoritiesProvider;

/**
 * Registro de implementaciones de proveedores de datos de autorización
 */
final class AuthoritiesProviderRegistry {
    private static final AuthoritiesProviderRegistry INSTANCE = new AuthoritiesProviderRegistry();
    private final List<AuthoritiesProvider> providers = new ArrayList<AuthoritiesProvider>();

    private AuthoritiesProviderRegistry() {
        ServiceLoader<AuthoritiesProvider> loader = ServiceLoader.load(AuthoritiesProvider.class);
        Iterator<AuthoritiesProvider> it = loader.iterator();
        while (it.hasNext()) {
            providers.add(it.next());
        }

        if (providers.isEmpty()) {
            throw new IllegalArgumentException("No se ha definido un provedor de autorización");
        }

        // Ordenación por prioridad
        Collections.sort(providers, new Comparator<AuthoritiesProvider>() {

            @Override
            public int compare(AuthoritiesProvider o1, AuthoritiesProvider o2) {
                if (o1.getPriority() == o2.getPriority()) {
                    return 0;
                }

                return o1.getPriority() < o2.getPriority() ? -1 : 1;
            }
        });
    }

    public static AuthoritiesProviderRegistry getInstance() {
        return INSTANCE;
    }

    public List<AuthoritiesProvider> getProviders() {
        return providers;
    }

}
