/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization.builder;

import java.util.List;

import es.xunta.amtega.transversal.authorization.AuthoritiesProvider;
import es.xunta.amtega.transversal.authorization.Authorization;

/**
 * Clase de utilidad para crear la información de contexto de ejecución para
 * peticiones de datos de autorización
 */
public final class AuthorizationBuilder {
    private AuthorizacionContext context = new AuthorizacionContext();

    /**
     * Establece el valor de código de aplicación de origen, aplicación para la
     * que se recuperará la información de autorización
     * 
     * @param application
     *            código de aplicación
     * @return instancia de builder
     */
    public AuthorizationBuilder setApplication(String application) {
        context.setApplication(application);
        return this;
    }

    /**
     * Establece el valor de token de validación para realizar consultas al
     * sistema de autorización
     * 
     * @param token
     *            valor de token
     * @return instancia de builder
     */
    public AuthorizationBuilder setToken(String token) {
        context.setToken(token);
        return this;
    }

    /**
     * Añade un parámetro adicional para realizar la consulta de datos de
     * autorización
     * 
     * @param key
     *            clave de parámetro
     * @param value
     *            valor del parámetro
     * @return instancia de builder
     */
    public AuthorizationBuilder addParam(String key, Object value) {
        context.getParams().put(key, value);
        return this;
    }

    /**
     * Crea una instancia del componente de autorización
     * 
     * @return instancia de cliente autorización
     */
    public Authorization build() {
        List<AuthoritiesProvider> providers = AuthoritiesProviderRegistry.getInstance().getProviders();
        return new AuthorizationImpl(context, providers);
    }

    /**
     * Crea una instancia de clase de utilidad para la creación de contexto de
     * autorización
     * 
     * @return instancia de builder
     */
    public static AuthorizationBuilder newBuilder() {
        return new AuthorizationBuilder();
    }

}
