/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization.builder;

import java.util.ArrayList;
import java.util.List;

import es.xunta.amtega.transversal.authorization.AuthoritiesProvider;
import es.xunta.amtega.transversal.authorization.Authorization;
import es.xunta.amtega.transversal.authorization.Context;
import es.xunta.amtega.transversal.authorization.Policy;
import es.xunta.amtega.transversal.authorization.Subject;

/**
 * Implementación por defecto de componente de autorización
 */
final class AuthorizationImpl implements Authorization {
    private final Context context;
    private final List<AuthoritiesProvider> providers;

    public AuthorizationImpl(Context context, List<AuthoritiesProvider> providers) {
        this.context = context;
        this.providers = new ArrayList<AuthoritiesProvider>(providers);
    }

    @Override
    public Policy getAuthorization(Subject<?> subject) {
        for (AuthoritiesProvider provider : providers) {
            // Se utiliza el primer proveedor que acepte el tipo de
            // identificador
            // Los proveedores están ordenados por prioridad
            if (provider.supports(subject.getType())) {
                return provider.getAuthorities(subject, context);
            }
        }

        throw new IllegalStateException("No hay proveedores definidos para este tipo de identificador");
    }

}
