/* amtega-common-authorization: Componente de autorizacion
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-authorization”.
*
* "amtega-common-authorization" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-authorization" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.authorization.builder;

import es.xunta.amtega.transversal.authorization.Subject;

/**
 * Clase de utilidad para crear objetos de identificación de usuarios
 */
public final class SubjectBuilder {

    private SubjectBuilder() {
    }

    /**
     * Crea un objeto de identificador de usuario empleando como identificador
     * un dato de tipo String
     * 
     * @param identifier
     *            identificador de usuario
     * @return identificador de usuario de tipo String
     */
    public static Subject<String> newSubject(final String identifier) {
        return new Subject<String>() {

            @Override
            public String getIdentifier() {
                return identifier;
            }

            @Override
            public Class<String> getType() {
                return String.class;
            }
        };
    }

    /**
     * Crea un objeto de identificador de usuario empleando como identificador
     * un dato de tipo Long
     * 
     * @param identifier
     *            identificador de usuario
     * @return identificador de usuario de tipo Long
     */
    public static Subject<Long> newSubject(final Long identifier) {
        return new Subject<Long>() {

            @Override
            public Long getIdentifier() {
                return identifier;
            }

            @Override
            public Class<Long> getType() {
                return Long.class;
            }
        };
    }

}
