/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.ServiceLoader;

/**
 * Clase de utilidad que gestiona la obtención del proveedor de archivos de configuración
 */
final class PropertiesSourceRegistry {
    private static final PropertiesSourceRegistry INSTANCE = new PropertiesSourceRegistry();
    private final List<PropertiesSource> sources;

    /**
     * Constructor privado
     */
    private PropertiesSourceRegistry() {
        this.sources = findPropertiesSources();
    }

    /**
     * Obtiene una instancia única (singleton)
     * @return Instancia
     */
    public static PropertiesSourceRegistry getInstance() {
        return INSTANCE;
    }

    /**
     * Obtiene los orígenes de datos
     * @return Orígenes
     */
    public Collection<PropertiesSource> getPropertiesSources() {
        return sources;
    }

    /**
     * Obtiene los orígenes de datos de una clase determinada
     * @param cls Clase a buscar
     * @return Orígnes de datos que cumplen el requisito
     */
    private List<PropertiesSource> findPropertiesSources() {
        final ServiceLoader<PropertiesSource> loader = ServiceLoader.load(PropertiesSource.class);
        Iterator<PropertiesSource> it = loader.iterator();
        boolean hasSources = it.hasNext();
        if (!hasSources) {
            return Collections.<PropertiesSource>emptyList();
        }

        final List<PropertiesSource> availableSources = new ArrayList<PropertiesSource>();
        while (it.hasNext()) {
            availableSources.add(it.next());
        }

        return availableSources;
    }

}
