/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration.environment;

import es.xunta.amtega.transversal.configuration.exception.UndefinedSystemPropertyException;

/**
 * Clase de utilidad para recuperar los valores de las distintas variables de
 * entorno definidas
 */
final class DefaultEnvironmentVariablesProvider implements EnvironmentVariablesProvider {

    private static final String BASE_PATH_PROPERTY = "apps_base_path";
    private static final String ENVIRONMENT_PROPERTY = "apps_env";
    private static final String SERVER_NAME_PROPERTY = "server.name";
    private static final int PRIORITY = 100;

    @Override
    public String getLogPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getCertPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getConfigPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getResourcesPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getTempPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getDataPath() {
        return getValue(BASE_PATH_PROPERTY);
    }

    @Override
    public String getEnvironment() {
        return getValue(ENVIRONMENT_PROPERTY);
    }

    @Override
    public String getServerName() {
        return getValue(SERVER_NAME_PROPERTY);
    }

    @Override
    public int getPriority() {
        return PRIORITY;
    }

    /**
     * Comprueba que existe y lee una propiedad del sistema
     * 
     * @param key Nombre de la variable de entorno
     * @return valor de propiedad definida en sistema
     */
    private String getValue(String key) {
        final String property = System.getProperty(key);
        if (!hasValue(property)) {
            throw new UndefinedSystemPropertyException("La propiedad de sistema " + key + " no está definida");
        }
        return property;
    }

    /**
     * Comprueba si una propiedad tiene valor
     * @param property Propiedad
     * @return Si tiene valor
     */
    private boolean hasValue(String property) {
        return property != null && !"".equals(property);
    }

}
