/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration.environment;

/**
 * Clase de utilidad para recuperar los valores de las variables de entorno
 * definidas. La implementación para recuperar los valores de entorno se puede
 * reemplazar por ServiceLoader implementando la interfaz
 * EnvironmentVariablesProvider
 */
public final class EnvironmentVariables {
    
    /**
     * Constructor privado
     */
    private EnvironmentVariables() {
    }

    /**
     * Recupera el valor de la variable de ruta de logs
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getLogPath() {
        return getProvider().getLogPath();
    }

    /**
     * Recupera el valor de la variable de ruta de certificados
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getCertPath() {
        return getProvider().getCertPath();
    }

    /**
     * Recupera el valor de la variable de ruta de configuración
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getConfigPath() {
        return getProvider().getConfigPath();
    }

    /**
     * Recupera el valor de la variable de ruta de recursos de aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getResourcesPath() {
        return getProvider().getResourcesPath();
    }

    /**
     * Recupera el valor de la variable de ruta de ficheros temporales
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getTempPath() {
        return getProvider().getTempPath();
    }

    /**
     * Recupera el valor de la variable de ruta de datos permanentes
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getDataPath() {
        return getProvider().getDataPath();
    }

    /**
     * Recupera el valor de la variable de entorno de ejecución
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getEnvironment() {
        return getProvider().getEnvironment();
    }

    /**
     * Recupera el valor de la variable de ruta de nombre de servidor en el que
     * se ejecuta la aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    public static String getServerName() {
        return getProvider().getServerName();
    }
    
    /**
     * Obtiene la instancia del proveedor de variables de entorno
     * @return Proveedor
     */
    private static EnvironmentVariablesProvider getProvider() {
        return EnvironmentVariablesProviderRegistry.getInstance().getProvider();
    }

}
