/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration.environment;

/**
 * Interfaz que define los métodos que dispone una aplicación para obtener las
 * variables de entorno
 */
public interface EnvironmentVariablesProvider {
    
    /**
     * Recupera el valor de la variable de ruta de logs
     * 
     * @return valor definido en la variable de entorno
     */
    String getLogPath();

    /**
     * Recupera el valor de la variable de ruta de certificados
     * 
     * @return valor definido en la variable de entorno
     */
    String getCertPath();

    /**
     * Recupera el valor de la variable de ruta de ficheros de configuración de
     * la aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    String getConfigPath();

    /**
     * Recupera el valor de la variable de ruta de recursos de la aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    String getResourcesPath();

    /**
     * Recupera el valor de la variable de ruta a directorio de temporales de la
     * aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    String getTempPath();

    /**
     * Recupera el valor de la variable de ruta al directorio de datos
     * permanentes de la aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    String getDataPath();

    /**
     * Recupera el valor de la variable de entorno de ejecución [dev,stg,prd]
     * 
     * @return valor definido en la variable de entorno
     */
    String getEnvironment();

    /**
     * Recupera el valor de la variable de nombre de servidor en el que se
     * ejecuta la aplicación
     * 
     * @return valor definido en la variable de entorno
     */
    String getServerName();

    /**
     * Prioridad del proveedor (menor valor = mayor prioridad)
     * 
     * @return prioridad
     */
    int getPriority();
}
