/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration.environment;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.ServiceLoader;

/**
 * Clase de utilidad que gestiona la obtención del proveedor de variables de configuración
 */
final class EnvironmentVariablesProviderRegistry {
    private static final EnvironmentVariablesProviderRegistry INSTANCE = new EnvironmentVariablesProviderRegistry();
    private final EnvironmentVariablesProvider provider;

    private EnvironmentVariablesProviderRegistry() {
        ServiceLoader<EnvironmentVariablesProvider> loader = ServiceLoader.load(EnvironmentVariablesProvider.class);
        Iterator<EnvironmentVariablesProvider> it = loader.iterator();
        boolean hasProviders = it.hasNext();
        provider = hasProviders ? getByPriority(it) : new DefaultEnvironmentVariablesProvider();
    }

    public EnvironmentVariablesProvider getProvider() {
        return provider;
    }

    public static EnvironmentVariablesProviderRegistry getInstance() {
        return INSTANCE;
    }

    private EnvironmentVariablesProvider getByPriority(Iterator<EnvironmentVariablesProvider> it) {
        // Si se definen proveedores se utiliza el de mayor prioridad
        final List<EnvironmentVariablesProvider> providers = new ArrayList<EnvironmentVariablesProvider>();
        while (it.hasNext()) {
            providers.add((EnvironmentVariablesProvider) it.next());
        }

        // Ordenación por prioridad
        Collections.sort(providers, new Comparator<EnvironmentVariablesProvider>() {

            @Override
            public int compare(EnvironmentVariablesProvider o1, EnvironmentVariablesProvider o2) {
                if (o1.getPriority() == o2.getPriority()) {
                    return 0;
                }

                return o1.getPriority() < o2.getPriority() ? -1 : 1;
            }
        });

        return providers.get(0);
    }

}
