/* amtega-common-configuration: Amtega Common Configuration
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-configuration”.
*
* "amtega-common-configuration" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-configuration" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.configuration.environment;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.junit.After;
import org.junit.Test;

import es.xunta.amtega.transversal.configuration.exception.UndefinedSystemPropertyException;

/**
 * Test de validación de uso de implementación propia de
 * EnviromentVariablesProvider
 */
public class DefaultEnvironmentVariablesProviderTest {
    
    private static final Logger LOGGER = LogManager.getLogger(DefaultEnvironmentVariablesProviderTest.class);
    
    private static final String BASE_PATH = "/path/apps";
    private static final String ENVIRONMENT = "mi-env";
    private static final String SERVER = "mi-server";
    
    private EnvironmentVariablesProvider instance = new DefaultEnvironmentVariablesProvider();
    
    @After
    public void tearDown() {
        System.clearProperty("apps_base_path");
        System.clearProperty("apps_env");
        System.clearProperty("server.name");
    }

    @Test
    public void validateEnvironmentVariables() {
        System.setProperty("apps_base_path", BASE_PATH);
        System.setProperty("apps_env", ENVIRONMENT);
        // Valido
        assertThat(instance.getLogPath(), is(BASE_PATH));
        assertThat(instance.getCertPath(), is(BASE_PATH));
        assertThat(instance.getConfigPath(), is(BASE_PATH));
        assertThat(instance.getResourcesPath(), is(BASE_PATH));
        assertThat(instance.getTempPath(), is(BASE_PATH));
        assertThat(instance.getDataPath(), is(BASE_PATH));
        assertThat(instance.getEnvironment(), is(ENVIRONMENT));
    }

    @Test
    public void throwExceptionIfNoEnvironmentVariable() {
        try {
            instance.getLogPath();
            fail("Se debe lanzar excepción");
        } catch (UndefinedSystemPropertyException e) {
            LOGGER.debug("Se cumple la condición de test", e);
        }
    }

    @Test
    public void serverName() {
        try {
            instance.getServerName();
            fail("Se debe lanzar excepción");
        } catch (UndefinedSystemPropertyException e) {
            LOGGER.debug("Se cumple la condición de test", e);
        }
        System.setProperty("server.name", SERVER);
        assertThat(instance.getServerName(), is(SERVER));
    }

}
