/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging;

import java.io.Serializable;

/**
 * Define la información que debe proporcionar una excepción para registro de
 * errores
 */
public interface AuditableException extends Serializable {

    /**
     * Identificador del sistema que provoca el error: Base de datos, reporting,
     * gestor documental, etc.
     * 
     * @return Identificador de sistema
     */
    String getSistema();

    /**
     * Tipificación del error
     * 
     * @return Tipo de error
     */
    TipoError getTipoError();

    /**
     * Nivel de criticidad del error
     * 
     * @return Criticidad
     */
    Criticidad getCriticidad();

    /**
     * Identificador del tipo de error
     * 
     * @return Código de error
     */
    String getCodigoError();

    /**
     * Observaciones (opcional)
     * 
     * @return Observaciones
     */
    String getObservaciones();

    /**
     * Recupera la información de la excepción original
     * 
     * @return Mensaje
     */
    String getMensaje();

}
