/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.converter;

import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.config.plugins.Plugin;
import org.apache.logging.log4j.core.pattern.ConverterKeys;
import org.apache.logging.log4j.message.Message;

import es.xunta.amtega.transversal.logging.AuditableMessage;

/**
 * Converter que permite escribir en log información de mensajes de tipo
 * auditable. Busca los objetos de tipo AuditableMessage en los parámetros y
 * escribe el atributo indicado por parámetro %s{atributo}
 */
@Plugin(name = "AuditableMessagePatternConverter", category = "Converter")
@ConverterKeys({ "s" })
public final class AuditableMessagePatternConverter extends GenericPatternConverter {

    /**
     * Constructor protegido
     * @param name Nombre del conversor
     * @param style Estilo
     * @param options Opciones
     */
    protected AuditableMessagePatternConverter(String name, String style, String[] options) {
        super(name, style, options);
    }
    
    /**
     * Crea una instancia del conversor
     * @param options Opciones
     * @return Conversor
     */
    public static AuditableMessagePatternConverter newInstance(final String[] options) {
        return new AuditableMessagePatternConverter("AuditableMessagePatternConverter", "auditable-message", options);
    }

    @Override
    public void format(LogEvent event, StringBuilder toAppendTo) {
        final Message message = event.getMessage();
        final Object[] params = message.getParameters();
        if (params != null) {
            for (Object messageParam : params) {
                appendParamValue(messageParam, toAppendTo);
            }
        }
    }
    
    /**
     * Añade el valor de un parámetro
     * @param messageParam Parámetro
     * @param toAppendTo Buffer de log
     */
    private void appendParamValue(Object messageParam, StringBuilder toAppendTo) {
        if (messageParam instanceof AuditableMessage) {
            for (String property : getOptions()) {
                final Object value = ((AuditableMessage) messageParam).getProperty(property);
                toAppendTo.append(cleanValue(value));
            }
        }
    }

}