/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.converter;

import java.util.Iterator;
import java.util.ServiceLoader;

import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.status.StatusLogger;

import es.xunta.amtega.transversal.logging.AuditingDataProvider;

/**
 * Crea y almacena la instancia de proveedor de auditoría
 */
final class AuditingDataProviderRegistry {
    private static final Logger LOGGER = StatusLogger.getLogger();
    private static final AuditingDataProviderRegistry INSTANCE = new AuditingDataProviderRegistry();
    private AuditingDataProvider dataProvider;

    /**
     * Constructor privado
     */
    private AuditingDataProviderRegistry() {
        ServiceLoader<AuditingDataProvider> loader = ServiceLoader.load(AuditingDataProvider.class);
        Iterator<AuditingDataProvider> it = loader.iterator();
        if (it.hasNext()) {
            dataProvider = it.next();
        } else {
            LOGGER.warn("No se ha encontrado un proveedor de auditoría, se utiliza proveedor NA");
            dataProvider = new NaAuditingDataProvider();
        }
    }
    
    /**
     * Devuelve la instancia única
     * @return Instancia
     */
    public static AuditingDataProviderRegistry getInstance() {
        return INSTANCE;
    }

    /**
     * Crea la instancia de proveedor de auditoría o utiliza la existente
     * 
     * @return instancia de proveedor de auditoría
     */
    public AuditingDataProvider getDataProvider() {
        return dataProvider;
    }

}
