/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.converter;

import java.lang.reflect.Method;

/**
 * Clase de utilidades para manipulación de Beans
 */
final class BeanUtils {

    public static final String GET = "get";

    /**
     * Constructor privado
     */
    private BeanUtils() {
    }

    /**
     * Crea el nombre del método get para obtener la propiedad
     * 
     * @param attribute Nombre de la propiedad
     * @return Valor de la propiedad
     */
    private static String createGetter(final String attribute) {
        // Por convención se accede a los métodos por el getter en formato
        // camelcase
        final StringBuilder sb = new StringBuilder();
        sb.append(GET);
        sb.append(attribute.substring(0, 1).toUpperCase());
        sb.append(attribute.substring(1, attribute.length()));
        return sb.toString();
    }

    /**
     * Recupera el valor de un atributo en el objeto empleando el getter del
     * atributo
     * 
     * @param attributeName
     * @param target
     * @return valor devuelto por el método getter
     * @throws ReflectiveOperationException
     */
    public static Object getValue(final String attributeName, final Object target) throws ReflectiveOperationException {
        final String methodName = attributeName.startsWith(GET) ? attributeName : createGetter(attributeName);
        final Method method = target.getClass().getMethod(methodName);
        return method.invoke(target);
    }

}
