/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.converter;

import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.config.plugins.Plugin;
import org.apache.logging.log4j.core.pattern.ConverterKeys;

import es.xunta.amtega.transversal.logging.AuditableException;
import es.xunta.amtega.transversal.logging.StringPool;

/**
 * Converter que permite escribir en log información proveniente de excepciones.
 * Escribe en log el valor del atributo indicado como %e{atributo}
 */
@Plugin(name = "ExceptionAttributePatternConverter", category = "Converter")
@ConverterKeys({ "e" })
public final class ExceptionPatternConverter extends GenericPatternConverter {

    /**
     * Constructor protegido
     * @param name Nombre del conversor
     * @param style Estilo
     * @param options Opciones
     */
    protected ExceptionPatternConverter(String name, String style, String[] options) {
        super(name, style, options);
    }

    /**
     * Crea una instancia del conversor
     * @param options Opciones
     * @return Conversor
     */
    public static ExceptionPatternConverter newInstance(final String[] options) {
        return new ExceptionPatternConverter("ExceptionAttributePatternConverter", "exception", options);
    }

    @Override
    public void format(LogEvent event, StringBuilder toAppendTo) {
        final Throwable th = event.getThrown();
        if (th != null && th instanceof AuditableException) {
            for (String attribute : getOptions()) {
                try {
                    final Object value = BeanUtils.getValue(attribute, th);
                    toAppendTo.append(cleanValue(value));
                } catch (Exception e) {
                    LOGGER.error("Error al procesar bean", e);
                    toAppendTo.append(StringPool.NA);
                }
            }
        }
    }

}