/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.converter;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import org.apache.logging.log4j.core.pattern.LogEventPatternConverter;

/**
 * Clase genérica de converter con funcionalidades comunes
 */
abstract class GenericPatternConverter extends LogEventPatternConverter {

    private static final String PIPE_REGEXP = "\\|";
    private static final String PIPE_REPLACEMENT = "##";
    private List<String> options;

    /**
     * Constructor
     * @param name Nombre del conversor
     * @param style Estilo 
     * @param options Opciones
     */
    protected GenericPatternConverter(String name, String style, String[] options) {
        super(name, style);
        this.options = options == null ? Collections.<String>emptyList() : Arrays.asList(options);
    }

    /**
     * Opciones indicadas en la definición del patrón %*{opcion}
     * 
     * @return lista de opciones
     */
    protected List<String> getOptions() {
        return this.options;
    }

    /**
     * Reemplaza los valores no permitidos que puedan existir en el texto
     * p.e.: <code>(* |## )</code>
     * 
     * @param valueToClean valor a limpiar
     * @return valor sin caracteres no válidos
     */
    protected String cleanValue(Object valueToClean) {
        return String.valueOf(valueToClean).replaceAll(PIPE_REGEXP, PIPE_REPLACEMENT);
    }

    @Override
    public boolean handlesThrowable() {
        // No muestra información de stacktrace
        return true;
    }

}
