/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging.exception;

import static es.xunta.amtega.transversal.logging.StringPool.EMPTY;

import es.xunta.amtega.transversal.logging.AuditableException;
import es.xunta.amtega.transversal.logging.Criticidad;
import es.xunta.amtega.transversal.logging.TipoError;

/**
 * Clase genérica para el registro de excepciones con datos de categorización
 * del error
 */
public class GenericAuditableException extends Exception implements AuditableException {

    private static final long serialVersionUID = -8411848958178927691L;
    private final String sistema;
    private final TipoError tipoError;
    private final Criticidad criticidad;
    private final String codigoError;
    private final String observaciones;

    /**
     * Constructor
     * @param sistema Sistema donde se produjo la excepción
     * @param tipoError Tipo de error
     * @param criticidad Criticidad del error
     * @param codigoError Código del error dentro de la aplicación
     * @param mensaje Mensaje de error
     * @param observaciones Observaciones
     * @param causa Excepción original
     */
    public GenericAuditableException(String sistema, TipoError tipoError, Criticidad criticidad, String codigoError,
            String mensaje, String observaciones, Throwable causa) {
        super(mensaje, causa);
        this.sistema = sistema;
        this.tipoError = tipoError;
        this.criticidad = criticidad;
        this.codigoError = codigoError;
        this.observaciones = observaciones;
    }

    /**
     * Constructor
     * @param sistema Sistema donde se produjo la excepción
     * @param tipoError Tipo de error
     * @param criticidad Criticidad del error
     * @param codigoError Código del error dentro de la aplicación
     * @param mensaje Mensaje de error
     */
    public GenericAuditableException(String sistema, TipoError tipoError, Criticidad criticidad, String codigoError,
            String mensaje) {
        this(sistema, tipoError, criticidad, codigoError, mensaje, EMPTY, null);
    }

    /**
     * Constructor
     * @param sistema Sistema donde se produjo la excepción
     * @param tipoError Tipo de error
     * @param criticidad Criticidad del error
     * @param codigoError Código del error dentro de la aplicación
     * @param mensaje Mensaje de error
     */
    public GenericAuditableException(String sistema, TipoError tipoError, Criticidad criticidad, int codigoError,
            String mensaje) {
        this(sistema, tipoError, criticidad, String.valueOf(codigoError), mensaje, EMPTY, null);
    }

    /**
     * Constructor
     * @param sistema Sistema donde se produjo la excepción
     * @param tipoError Tipo de error
     * @param criticidad Criticidad del error
     * @param codigoError Código del error dentro de la aplicación
     * @param mensaje Mensaje de error
     * @param causa Exepción original
     */
    public GenericAuditableException(String sistema, TipoError tipoError, Criticidad criticidad, String codigoError,
            String mensaje, Throwable causa) {
        this(sistema, tipoError, criticidad, codigoError, mensaje, EMPTY, causa);
    }

    /**
     * Constructor
     * @param sistema Sistema donde se produjo la excepción
     * @param tipoError Tipo de error
     * @param criticidad Criticidad del error
     * @param codigoError Código del error dentro de la aplicación
     * @param mensaje Mensaje de error
     * @param causa Exepción original
     */
    public GenericAuditableException(String sistema, TipoError tipoError, Criticidad criticidad, int codigoError,
            String mensaje, Throwable causa) {
        this(sistema, tipoError, criticidad, String.valueOf(codigoError), mensaje, EMPTY, causa);
    }

    @Override
    public final TipoError getTipoError() {
        return tipoError;
    }

    @Override
    public final Criticidad getCriticidad() {
        return criticidad;
    }

    @Override
    public final String getCodigoError() {
        return codigoError;
    }

    @Override
    public final String getObservaciones() {
        return observaciones;
    }

    @Override
    public final String getSistema() {
        return sistema;
    }

    @Override
    public final String getMensaje() {
        return getMessage();
    }

}
