/* amtega-common-logging: Amtega Common Logging
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-logging".
*
* "amtega-common-logging" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-logging" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.logging;

import static org.junit.Assert.assertEquals;

import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.junit.Test;

import es.xunta.amtega.transversal.logging.appender.StringAppender;
import es.xunta.amtega.transversal.logging.exception.GenericAuditableException;

public class LoggingTestSuite {
    private static final Logger LOGGER = LogManager.getLogger(LoggingTestSuite.class);
    private static final int ERROR_CODE = 123;

    @Test
    public void auditingTest() {
        String name = "auditing";
        StringAppender appender = StringAppender
                .createStringAppender("|%a{usuario}|%a{ip}|%a{servidor}|%a{version}|%m|");
        appender.addToLogger(name, Level.INFO);
        appender.start();

        // Log to the string appender
        LOGGER.error("Auditing data test");

        appender.removeFromLogger(name);

        assertEquals("|dummy|dummy|dummy|1.0|Auditing data test|", appender.getOutput());
    }

    @Test
    public void exceptionTest() {
        String name = "excep";
        StringAppender appender = StringAppender
                .createStringAppender("|%e{tipoError}|%e{criticidad}|%e{codigoError}|%e{mensaje}|");
        appender.addToLogger(name, Level.INFO);
        appender.ignoreExceptions();
        appender.start();

        // Log to the string appender
        LOGGER.error("Error forzado: ", new GenericAuditableException("BBDD", TipoError.BASE_DATOS, Criticidad.ALTO,
                ERROR_CODE, "Error de base de datos"));

        appender.removeFromLogger(name);

        assertEquals("|3|2|123|Error de base de datos|", appender.getOutput());
    }

}
