/* amtega-common-test: Amtega Test Utils
*
* Copyright (C) 2018 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-test".
*
* "amtega-common-test" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.2 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-test" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.test.configuration;

import java.io.File;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import es.xunta.amtega.transversal.configuration.environment.EnvironmentVariablesProvider;
import es.xunta.amtega.transversal.test.util.AmtegaTest;
import es.xunta.amtega.transversal.test.util.AmtegaTestConstants;

/**
 * Provider de variables de entorno Amtega apuntando al directorio "root" de test
 */
public class ClasspathRootEnvironmentVariablesProvider implements EnvironmentVariablesProvider {
    
    private static final Logger LOGGER = LogManager.getLogger(ClasspathRootEnvironmentVariablesProvider.class);

    @Override
    public String getCertPath() {
        return this.buildPath("cert");
    }

    @Override
    public String getConfigPath() {
        return this.buildPath("config");
    }

    @Override
    public String getDataPath() {
        return this.buildPath("data");
    }

    @Override
    public String getLogPath() {
        return this.buildPath("log");
    }

    @Override
    public String getResourcesPath() {
        return this.buildPath("resource");
    }

    @Override
    public String getTempPath() {
        return this.buildPath("temp");
    }

    @Override
    public String getEnvironment() {
        return AmtegaTestConstants.ENVIRONMENT;
    }

    @Override
    public String getServerName() {
        return AmtegaTestConstants.SERVER_NAME;
    }

    @Override
    public int getPriority() {
        return 0;
    }

    /**
     * Constrúe a ruta
     * @param key Clave
     * @return Ruta completa
     */
    private String buildPath(String key) {
        return getRootPath().concat(key).concat(File.separator);
    }

    /**
     * Obtén a ruta base onde están ubicados os directorios Amtega
     * @return Ruta base
     */
    private String getRootPath() {
        String rootPath = AmtegaTest.getRootBasePath();
        LOGGER.info("Estableciendo directorio raíz de recursos de la aplicación: {}", rootPath);
        // Ruta absoluta al directorio en función del SO
        return rootPath;
    }

}
