/* amtega-common-test: Amtega Test Utils
*
* Copyright (C) 2018 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-test".
*
* "amtega-common-test" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.2 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-test" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.test.configuration;

import java.io.File;

import es.xunta.amtega.transversal.configuration.environment.EnvironmentVariablesProvider;
import es.xunta.amtega.transversal.configuration.exception.UndefinedSystemPropertyException;
import es.xunta.amtega.transversal.test.util.AmtegaTest;
import es.xunta.amtega.transversal.test.util.AmtegaTestConstants;

/**
 * Provider de variables de entorno Amtega apuntando al directorio "root" de test,
 * estableciendo dichas rutas como variables de entorno (hay componentes que las leen directamente)
 */
public class TestSystemEnvironmentVariablesProvider implements EnvironmentVariablesProvider {
    
    /**
     * Constructor
     */
    public TestSystemEnvironmentVariablesProvider() {
        // Definimos las rutas como variables de entorno
        // Hay componentes que acceden direcamente a estas variables (en modo estático), por lo que es necesario emularlo 100%
        AmtegaTest.setTestEnvironmentVariables();
    }

    @Override
    public String getCertPath() {
        return this.buildPath("cert");
    }

    @Override
    public String getConfigPath() {
        return this.buildPath("config");
    }

    @Override
    public String getDataPath() {
        return this.buildPath("data");
    }

    @Override
    public String getLogPath() {
        return this.buildPath("log");
    }

    @Override
    public String getResourcesPath() {
        return this.buildPath("resource");
    }

    @Override
    public String getTempPath() {
        return this.buildPath("temp");
    }

    @Override
    public String getEnvironment() {
        return AmtegaTestConstants.ENVIRONMENT;
    }

    @Override
    public String getServerName() {
        return AmtegaTestConstants.SERVER_NAME;
    }

    @Override
    public int getPriority() {
        return 0;
    }

    /**
     * Constrúe a ruta
     * @return Ruta configurada
     */
    protected String buildPath(String key) {
        final String property = System.getProperty(AmtegaTestConstants.PATH_SYSTEM_PROP);
        if (property == null || property.isEmpty()) {
            throw new UndefinedSystemPropertyException("La propiedad de sistema "+AmtegaTestConstants.PATH_SYSTEM_PROP+" no está definida");
        }
        String path = property.endsWith(File.separator) ? property : property.concat(File.separator);
        return path.concat(key).concat(File.separator);
    }

}
