/* amtega-common-test: Amtega Test Utils
*
* Copyright (C) 2018 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-test".
*
* "amtega-common-test" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.2 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-test" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.test.util;

import static org.hamcrest.Matchers.*;
import static org.junit.Assert.*;

import java.io.File;

import org.junit.Test;

/**
 * Clase de utilidades varias para testing
 */
public final class AmtegaTestTest {

    private static final String NA = "";
    private static final String AMTEGA_ROOT_FOLDER = "target/test-classes/root";

    @Test
    public void constructorShouldBePrivate() {
        AmtegaTest instance = AmtegaTest.callPrivateConstructor(AmtegaTest.class);
        assertThat(instance, notNullValue());
    }
    
    @Test
    public void callPrivateConstructorShouldReturnInstance() {
        PrivateConstructorClass instance = AmtegaTest.callPrivateConstructor(PrivateConstructorClass.class);
        assertThat(instance, notNullValue());
    }
    
    @Test
    public void getRootBasePathShouldReturnDefaultPath() {
        File expected = new File(AMTEGA_ROOT_FOLDER);
        File result = new File(AmtegaTest.getRootBasePath());
        assertThat(result.getAbsolutePath(), is(expected.getAbsolutePath()));
    }
    
    @Test
    public void setTestEnvironmentVariablesShouldEntablishEnvironmentVariables() {
        File root = new File(AMTEGA_ROOT_FOLDER);
        AmtegaTest.setTestEnvironmentVariables();
        assertThat(System.getProperty(AmtegaTestConstants.PATH_SYSTEM_PROP), is(this.buildPath(root)));
    }
    
    @Test
    public void setTestEnvironmentVariablesShouldModifyEnvironmentVariables() {
        File root = new File("target/test-classes/root-alternativo");
        AmtegaTest.setTestEnvironmentVariables(root.getAbsolutePath());
        assertThat(System.getProperty(AmtegaTestConstants.PATH_SYSTEM_PROP), is(this.buildPath(root)));
    }
    
    @Test
    public void cleanTestEnvironmentVariablesShouldDeleteEnvironmentVariables() {
        AmtegaTest.setTestEnvironmentVariables();
        AmtegaTest.cleanTestEnvironmentVariables();
        assertThat(System.getProperty(AmtegaTestConstants.PATH_SYSTEM_PROP), is(NA));
    }
    
    private String buildPath(File root) {
        return root.getAbsolutePath().concat(File.separator);
    }
    
    
    
    
    
    
    
    private static class PrivateConstructorClass {
        
        private PrivateConstructorClass() {
            
        }
        
    }

}
