/* amtega-common-test: Amtega Test Utils
*
* Copyright (C) 2018 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "amtega-common-test".
*
* "amtega-common-test" is free software: you can redistribute it and/or modify
* it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.2 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "amtega-common-test" is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.transversal.test.util;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import org.junit.Test;

import static org.junit.Assert.*;
import static org.hamcrest.Matchers.*;

public final class DateTestUtilTest {
    
    private static final String DATE_PATTERN = "yyyy-MM-dd HH:mm:ss.SSS";

    @Test
    public void constructorShouldBePrivate() {
        assertThat(AmtegaTest.callPrivateConstructor(DateTestUtil.class), notNullValue());
    }

    @Test
    public void createDateShouldReturnDate() {
        testCreateDate(2017, 0, 1, 0, 0, 0,  0, "2017-01-01 00:00:00.000");
        testCreateDate(2017, 0, 1, 5, 7, 8, 10, "2017-01-01 05:07:08.010");
        testCreateDate(2017,10,15,17,20,30,500, "2017-11-15 17:20:30.500");
        testCreateDate(2017,12, 1, 0, 0, 0,  0, "2018-01-01 00:00:00.000");
    }

    @Test
    public void addDateShouldReturnDate() {
        Date d = DateTestUtil.createDate(2017, 0, 1, 0, 0, 0,  0);
        assertThat(this.toString(DateTestUtil.add(d, Calendar.DATE, 2)), is("2017-01-03 00:00:00.000"));
        assertThat(this.toString(DateTestUtil.add(d, Calendar.MONTH, 5)), is("2017-06-01 00:00:00.000"));
        assertThat(this.toString(DateTestUtil.add(d, Calendar.HOUR, 22)), is("2017-01-01 22:00:00.000"));
        assertThat(this.toString(DateTestUtil.add(d, Calendar.HOUR, 30)), is("2017-01-02 06:00:00.000"));
    }

    @Test
    public void roundDateShouldReturnDate() {
        Date d = DateTestUtil.createDate(2017, 0, 1, 20, 10, 32,  0);
        assertThat(this.toString(DateTestUtil.roundTime(d)), is("2017-01-01 23:59:59.999"));
        assertThat(this.toString(DateTestUtil.roundTime(d, false)), is("2017-01-01 00:00:00.000"));
        assertThat(this.toString(DateTestUtil.roundTime(d, true)), is("2017-01-01 23:59:59.999"));
    }
    
    private void testCreateDate(int year, int month, int date, int hour, int minute, int second, int milisecond, String result) {
        Date d = DateTestUtil.createDate(year, month, date, hour, minute, second, milisecond);
        assertThat(this.toString(d), is(result));
    }
    
    private String toString(Date d) {
        return new SimpleDateFormat(DATE_PATTERN).format(d);
    }

}
