/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import java.util.Collection;
import java.util.Map;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.security.cas.authentication.CasAssertionAuthenticationToken;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.AuthenticationUserDetailsService;
import org.springframework.security.core.userdetails.UserDetails;

import es.xunta.amtega.codapp.autorizacion.AuthorizationService;

/**
 * Clase que recupera a información de usuario autenticado no CAS.
 * Recupera datos persoais proporcionados polo CAS e engade información
 * de autorización do usuario.
 */
final class CasAuthenticationUserDetailsServiceImpl implements AuthenticationUserDetailsService<CasAssertionAuthenticationToken> {
    
    private static final Logger LOGGER = LogManager.getLogger(CasAuthenticationUserDetailsServiceImpl.class);
    private final AuthorizationService authorizationService;
    private static final String NOMBRE = "nombre";
    private static final String APELLIDOS = "apellidos";
    private static final String NIF = "nif";
    
    /**
     * Constructor
     * @param authorizationService Servizo de autorización
     */
    public CasAuthenticationUserDetailsServiceImpl(AuthorizationService authorizationService) {
        this.authorizationService = authorizationService;
    }

    @Override
    public UserDetails loadUserDetails(CasAssertionAuthenticationToken token) {
        // Datos do usuario proporcionados polo CAS
        Map<String, Object> attributes = token.getAssertion().getPrincipal().getAttributes();
        String usuario = String.valueOf(token.getPrincipal());
        String nombre = String.valueOf(attributes.get(NOMBRE));
        String apellidos = String.valueOf(attributes.get(APELLIDOS));
        String nif = String.valueOf(attributes.get(NIF));
        LOGGER.debug("Información de usuario {} no CAS: {}", usuario, attributes);

        // Recuperamos información de autorización do usuario
        Collection<SimpleGrantedAuthority> authorities = authorizationService.getAuthorities(usuario);

        return new CustomUserDetailsImpl(nombre, apellidos, nif, usuario, authorities);
    }

}