/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jasig.cas.client.validation.Assertion;
import org.jasig.cas.client.validation.TicketValidationException;
import org.jasig.cas.client.validation.TicketValidator;

/**
 * Wrapper para validar tickets do CAS
 */
final class CasTicketValidator implements TicketValidator {

    private static final Logger LOGGER = LogManager.getLogger(CasTicketValidator.class);
    
    private final TicketValidator ticketValidator;

    /**
     * Constructor
     * @param ticketValidator Implementación específica do validador de tickets do CAS
     */
    public CasTicketValidator(TicketValidator ticketValidator) {
        this.ticketValidator = ticketValidator;
    }

    @Override
    public Assertion validate(String ticket, String service) throws TicketValidationException {
        try {
            return ticketValidator.validate(ticket, service);
        } catch(RuntimeException e) {
            // O CAS lanza erros 500 ocasionalmente ante tickets con caracteres especiais.
            // Ante estos erros, lanzamos unha excepción de validación de ticket.
            LOGGER.error("Erro ao validar o ticket no CAS", e);
            throw new TicketValidationException("Erro ao validar o ticket no CAS", e);
        }
    }
    
}
