/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.springframework.context.ApplicationEventPublisher;
import org.springframework.context.ApplicationEventPublisherAware;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationFailureHandler;

/**
 * Xestiona os erros de autenticación na aplicación.
 * Amosa unha advertencia tras "LOGIN_ATTEMPTS_THRESHOLD" intentos realizados
 */
public final class CustomAuthenticationFailureHandler extends SimpleUrlAuthenticationFailureHandler implements ApplicationEventPublisherAware  {
    
    protected static final String LOGIN_ATTEMPTS_ATTR = "loginAttempts";
    protected static final String LOGIN_ATTEMPTS_HUMAN_ATTR = "showHuman";
    protected static final String LOGIN_ERROR_ATTR = "showLoginError";
    protected static final int LOGIN_ATTEMPTS_THRESHOLD = 2;
    
    @Override
    public void setApplicationEventPublisher(ApplicationEventPublisher applicationEventPublisher) {
        // Baleiro
    }
    
    @Override
    public void onAuthenticationFailure(HttpServletRequest request, HttpServletResponse response, AuthenticationException exception) throws IOException, ServletException {
        // Metemos en sesión os intentos de login
        // Ao facer logout, invalídase a sesión Java, polo que non temos que "resetealo" a cero
        HttpSession session = request.getSession(true);
        
        // Mostramos al usuario un error de autenticación (independientemente del número de reintentos).
        session.setAttribute(LOGIN_ERROR_ATTR, Boolean.TRUE);
        
        Integer attempts = (Integer)session.getAttribute(LOGIN_ATTEMPTS_ATTR);
        if(attempts==null) {
            attempts = 0;
        }
        attempts++;
        session.setAttribute(LOGIN_ATTEMPTS_ATTR, attempts);
        // Comprobamos que se superan o número de intentos predefinido
        if(attempts>=LOGIN_ATTEMPTS_THRESHOLD) {
            session.setAttribute(LOGIN_ATTEMPTS_HUMAN_ATTR, Boolean.TRUE);
        }        
        // Delegamos cara arriba
        super.onAuthenticationFailure(request, response, exception);
    }


}
