/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.security.authentication.AuthenticationCredentialsNotFoundException;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.AuthenticationServiceException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import es.xunta.amtega.codapp.autorizacion.AuthorizationService;
import es.xunta.amtega.transversal.archam.core.exception.SistemaAutenticacionException;
import es.xunta.amtega.transversal.authentication.exception.CommunicationException;
import es.xunta.amtega.transversal.authentication.exception.InvalidLoginCredentialsException;
import es.xunta.amtega.transversal.utils.BaseUtils;

/**
 * Clase que implementa o servizo de autenticación de usuarios.
 */
final class CustomAuthenticationProviderImpl implements AuthenticationProvider {

    private static final Logger LOGGER = LogManager.getLogger(CustomAuthenticationProviderImpl.class);
    private final AuthorizationService authorizationService;
    private static final String NA = "";

    /**
     * Constructor
     * @param authorizationService Servizo de autorización
     */
    public CustomAuthenticationProviderImpl(AuthorizationService authorizationService) {
        this.authorizationService = authorizationService;
    }

    @Override
    public Authentication authenticate(Authentication authentication) {
        String username = authentication.getName();
        String password = String.valueOf(authentication.getCredentials());

        try {
            // Autenticación externa: empregamos libraría de autenticación
            BaseUtils.Authentication.login(username, password);
            
            // Recuperamos info de autorización para o usuario
            List<SimpleGrantedAuthority> authorities = authorizationService.getAuthorities(username);

            // Creamos información de usuario que se almacenará en sesión
            UserDetails userDetails = new CustomUserDetailsImpl(username, NA, NA, username, authorities);

            return new UsernamePasswordAuthenticationToken(userDetails, password, authorities);
        } catch (InvalidLoginCredentialsException e) {
            LOGGER.error("Erro de autenticación de usuario", new SistemaAutenticacionException(e));
            throw new AuthenticationCredentialsNotFoundException("Usuario ou contrasinal incorrectos", e);
        } catch (CommunicationException e) {
            LOGGER.error("Erro de comunicación co servizo de autenticación", new SistemaAutenticacionException(e.getMessage(), e));
            throw new AuthenticationServiceException("Erro de comunicación co servizo de autenticación", e);
        }
    }

    @Override
    public boolean supports(Class<?> cls) {
        return true;
    }

}
