/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import java.util.Collection;

import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.util.StringUtils;

/**
 * Implementación dos detalles de usuario, que actuará de "Principal"
 * na aplicación.
 */
final class CustomUserDetailsImpl extends User implements CustomUserDetails {
    private static final long serialVersionUID = 1L;
    private static final String SECRET_KEY_MASK = "*";
    private final String identificador;
    private final String nombre;
    private final String apellidos;
    private final String nif;

    /**
     * Constructor
     * @param nombre Nome
     * @param apellidos Apelidos
     * @param nif NIF
     * @param username Nome de usuario
     * @param authorities Información de autorización
     */
    public CustomUserDetailsImpl(String nombre, String apellidos, String nif, String username,
            Collection<? extends GrantedAuthority> authorities) {
        super(username, SECRET_KEY_MASK, authorities);
        
        if(StringUtils.isEmpty(nombre)) {
            throw new IllegalArgumentException("É obrigatorio indicar o nome");
        }
        
        this.identificador = username;
        this.nombre = nombre;
        this.apellidos = apellidos;
        this.nif = nif;
    }
    
    @Override
    public String getIdentificador() {
        return identificador;
    }

    @Override
    public String getNombre() {
        return nombre;
    }

    @Override
    public String getApellidos() {
        return apellidos;
    }

    @Override
    public String getNif() {
        return nif;
    }

}