/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autorizacion;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.springframework.security.core.authority.SimpleGrantedAuthority;

import es.xunta.amtega.transversal.authorization.Authorization;
import es.xunta.amtega.transversal.authorization.Policy;
import es.xunta.amtega.transversal.authorization.builder.AuthorizationBuilder;
import es.xunta.amtega.transversal.authorization.builder.SubjectBuilder;
import es.xunta.amtega.transversal.utils.BaseUtils;

/**
 * Implementación do servizo de autorización
 */
final class AuthorizationServiceImpl implements AuthorizationService {

    private final Authorization authorization;
    
    /**
     * Constructor
     */
    public AuthorizationServiceImpl() {
        // Empregamos o compoñente transversal de autorización
        String application = BaseUtils.Configuration.getApplicationCode();
        authorization = AuthorizationBuilder.newBuilder().setApplication(application).build();
    }

    @Override
    public List<SimpleGrantedAuthority> getAuthorities(String username) {
        // Recuperamos políticas de autorización do usuario
        Policy policy = authorization.getAuthorization(SubjectBuilder.newSubject(username));

        // Componemos información de autorización segundo Spring Security
        // Os roles represéntanse en Spring Security como ROLE_[identificador]
        List<SimpleGrantedAuthority> authorities = new ArrayList<>();
        Set<String> roles = policy.getRoles();
        for (String role : roles) {
            String value = ("ROLE_" + role).toUpperCase();
            authorities.add(new SimpleGrantedAuthority(value));
        }
        
        // O resto son considerados "permisos"
        Set<String> permissions = policy.getPermissions();
        for (String permission : permissions) {
            authorities.add(new SimpleGrantedAuthority(String.valueOf(permission.toUpperCase())));
        }

        return authorities;
    }

}
