/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autorizacion;

import java.util.Arrays;
import java.util.Collections;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import es.xunta.amtega.transversal.authorization.AuthoritiesProvider;
import es.xunta.amtega.transversal.authorization.Context;
import es.xunta.amtega.transversal.authorization.Policy;
import es.xunta.amtega.transversal.authorization.Subject;

/**
 * Implementación dummy de proveedor de datos de autorización para un usuario.
 * A libraría de autorización permite desenvolver implementacións propias de
 * proveedores de datos de autorización. Neste exemplo, sempre se devolven os
 * mesmos valores de perfil e permisos para o usuario.
 * Deberá ser substituída pola implementación propia da aplicación.
 * Esta implementación actívase por SPI a través de "src/main/resources/META-INF/services".
 */
public class CustomAuthoritiesProvider implements AuthoritiesProvider {
    
    /**
     * Asignamos unha prioridade alta para poder sobreescribir o comportamento
     * da libraría con outro proveedor con maior prioridade.
     */
    private static final int PRIORITY = 100;

    @Override
    public Policy getAuthorities(Subject<?> subject, Context context) {
        // Aquí poderiamos acceder á base de datos para recuperar información de permisos
        return new Policy() {
            @Override
            public Set<String> getRoles() {
                return Collections.singleton("USUARIO");
            }
            @Override
            public Set<String> getPermissions() {
                return new HashSet<>(Arrays.asList("ALTA_DOCUMENTO", "BORRAR_DOCUMENTO", "MODIFICAR_DOCUMENTO"));
            }
            @Override
            public Map<String, Object> getContext() {
                return Collections.emptyMap();
            }
        };
    }

    @Override
    public int getPriority() {
        return PRIORITY;
    }

    @Override
    public boolean supports(Class<?> cls) {
        // Esta implementación só soporta identificadores de usuario de tipo String
        return cls.isAssignableFrom(String.class);
    }

}
