/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.configuracion.web;

import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import org.apache.commons.io.IOUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;

import es.xunta.amtega.transversal.archam.core.exception.ResourceNotFoundException;

/**
 * Controlador para a xestión do módulo de configuración.
 */
@Controller
@RequestMapping("/configuracion")
public class ConfiguracionController {

    private static final Logger LOGGER = LogManager.getLogger(ConfiguracionController.class);
    
    private String changelogFile = "release-notes.txt";

    /**
     * Vista principal do menú de configuración.
     * @return Vista principal do menú de configuración.
     */
    @GetMapping
    public String configuration() {
        LOGGER.info("Accedendo á vista índice da configuración.");
        return "configuracion/index";
    }

    /**
     * Amosa a configuración do contorno e aplicación
     * @return Vista do sistema
     */
    @GetMapping("/sistema")
    public String sistema(ModelMap model) {
        LOGGER.info("Cargando a vista de configuración coa información do sistema.");
        model.addAttribute("changelog", loadChangelogContent());
        LOGGER.info("Vista de configuración coa información do sistema cargada.");
        return "configuracion/sistema";
    }

    /**
     * Carga o contido do ficheiro de cambios (Release Notes) da aplicación
     * @return Contido do ficheiro
     */
    private String loadChangelogContent() {
        try(InputStream inputStream = this.getClass().getClassLoader().getResourceAsStream(this.changelogFile)) {
            return IOUtils.toString(inputStream, StandardCharsets.UTF_8.name());
        } catch (Exception e) {
            ResourceNotFoundException rnfe = new ResourceNotFoundException("Error al leer el fichero "+this.changelogFile, e);
            LOGGER.error("Non se puido cargar a lista de cambios da aplicación", rnfe);
            throw rnfe;
        }
    }
    
    /**
     * Cambia o nome do ficheiro de changelog a cargar (orientado a tests)
     * @param file Ficheiro
     */
    protected void setChangelogFile(String file) {
        this.changelogFile = file;
    }

}
