/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.configuracion.web;

import javax.servlet.http.HttpServletRequest;

import es.xunta.amtega.transversal.plugin.annotation.Plugin;
import es.xunta.amtega.transversal.plugin.type.AbstractSidebarMenuEntry;

/**
 * Clase que permite, a través dun plugin, amosar no menú lateral
 * un punto de acceso ás funcionalidades do módulo de configuración.
 */
@Plugin(id = "ConfigurationSidebarMenuEntry")
public class ConfigurationSidebarMenuEntry extends AbstractSidebarMenuEntry {

    private static final String ID = "configuracion";
    private static final String TEXT = "layout.menu.left.configuracion";
    private static final String TITLE = "global.configuracion.title";
    private static final String BUNDLE_NAME = "i18n/MessagesConfiguracion";
    private static final String URL = "/configuracion";
    private static final int SORT = 99;
    private static final String ICON = "glyphicon glyphicon-cog";
    private static final String GRANTED_ROLE = "USUARIO";

    /**
     * Constructor
     */
    public ConfigurationSidebarMenuEntry() {
        super(ID, TEXT, TITLE, URL);
        this.setBundleName(BUNDLE_NAME);
    }

    @Override
    public int getSort() {
        return SORT;
    }

    @Override
    public String getClassName() {
        return ICON;
    }

    @Override
    public boolean isVisible(HttpServletRequest request) {
        // Menú só visible para usuarios cun ROL determinado
        return request.isUserInRole(GRANTED_ROLE);
    }

}
