/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos;

import java.util.Objects;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import javax.persistence.Version;
import javax.validation.constraints.Size;

import es.xunta.amtega.transversal.archam.core.data.EntidadAuditable;


/**
 * Entidade que representa un documento da biblioteca.
 */
@Entity
@Table(name = "documento")
public class Documento extends EntidadAuditable {

    private static final long serialVersionUID = 1L;

    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "documento_secuence_generator")
    @SequenceGenerator(name = "documento_secuence_generator", sequenceName = "documento_seq")
    private Long id;

    /*
     * Identificador de documento utilizado para compor a URL pública de
     * descarga e non expor o ID interno de BBDD, xa que o usuario podería
     * modificar o valor e acceder a outro rexistro.
     */
    @Column(length = 50, unique = true, nullable = false)
    private String uuid;
    @Size(min = 3, max = 250)
    @Column(unique = true)
    private String titulo;
    @Size(max = 250)
    private String descripcion;
    private String nombre;
    private String formato;
    private String path;
    @Version
    private Long version;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getTitulo() {
        return titulo;
    }

    public void setTitulo(String titulo) {
        this.titulo = titulo;
    }

    public String getNombre() {
        return nombre;
    }

    public void setNombre(String fichero) {
        this.nombre = fichero;
    }

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        this.descripcion = descripcion;
    }

    public String getFormato() {
        return formato;
    }

    public void setFormato(String formato) {
        this.formato = formato;
    }

    public String getPath() {
        return path;
    }

    public Long getVersion() {
        return version;
    }

    public void setVersion(Long version) {
        this.version = version;
    }

    public void setPath(String path) {
        this.path = path;
    }
    
    /**
     * Permite saber se se trata dun documento novo.
     *
     * @return <code>true</code> se se trata dun documento novo,
     * <code>false</code> en caso contrario.
     */
    public boolean isNew() {
        return id == null;
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(id);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj instanceof Documento) {
            Documento other = (Documento) obj;
            return Objects.equals(id, other.id);
        }

        return false;
    }

    @Override
    public String toString() {
        return "Documento [id=" + id + ", uuid=" + uuid + ", titulo=" + titulo + ", descripcion=" + descripcion
                + ", nombre=" + nombre + ", formato=" + formato + ", path=" + path + ", version=" + version
                + ", usuarioCreacion=" + getUsuarioCreacion() + ", fechaCreacion=" + getFechaCreacion()
                + ", usuarioUltimaModificacion=" + getUsuarioUltimaModificacion()
                + ", fechaUltimaModificacion=" + getFechaUltimaModificacion() + "]";
    }
    
}
