/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.repository.query.Param;

/**
 * Repositorio JPA de Spring Data para a biblioteca de documentos.
 */
interface DocumentoRepository extends JpaRepository<Documento, Long> {

    /**
     * Recupera un documento polo seu UUID.
     *
     * @param uuid UUID do documento a recuperar
     * @return Documento
     */
    Documento findOneByUuid(String uuid);
    
    /**
     * Recupera un documento a partir do título que o identifica.
     *
     * @param titulo Título do documento a recuperar.
     * @return Documento
     */
    Documento findOneByTitulo(String titulo);

    /**
     * Recupera unha páxina de resultados correspondentes a unha busca na
     * base de datos daqueles que conteñan no seu título o valor indicado,
     * ignorando a diferenza maiúsculas/minúsculas.
     *
     * @param query Título a buscar.
     * @param pageable Paxinación e ordeación dos resultados.
     * @return Páxina cos resultados.
     */
    Page<Documento> findByTituloLikeIgnoreCase(@Param("titulo") String query, Pageable pageable);

    /**
     * Recupera unha página de resultados correspondentes a una busca avanzada
     * na base de datos de documentos.
     *
     * @param specification Detalles do filtro de busca a aplicar.
     * @param pageable Paxinación e ordeación dos resultados.
     * @return Páxina cos resultados.
     */
    Page<Documento> findAll(Specification<Documento> specification, Pageable pageable);
    
}
