/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Expression;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;

import org.springframework.data.jpa.domain.Specification;
import org.springframework.util.StringUtils;

import es.xunta.amtega.transversal.archam.core.persistence.PredicateUtils;


/**
 * Eespecificacións (filtros avanzados) para a busca de documentos
 * na base de datos.
 */
class DocumentoSpecifications {
    
    /**
     * Constructor privado
     */
    private DocumentoSpecifications() {
        // Baleiro
    }

     /**
     * Crea a especificación de busca de documentos segundo o filtro.
     * 
     * @param filter Filtro cos criterios de busca.
     * @return Especificación para a busca en BD.
     */
    public static Specification<Documento> filterBy(final DocumentoFilter filter) {
        
        // Devolvemos unha implementación dun Specification, segundo os datos definidos no filtro
        return new Specification<Documento>() {
            
            @Override
            public Predicate toPredicate(Root<Documento> root, CriteriaQuery<?> query, CriteriaBuilder builder) {
                List<Predicate> predicates = new ArrayList<>();
                query.distinct(Boolean.TRUE);
                addPredicateFor("titulo", filter.getTitulo(), root, builder, predicates);
                addPredicateFor("nombre", filter.getNombre(), root, builder, predicates);
                addPredicateFor("formato", filter.getFormato(), root, builder, predicates);
                return builder.and(predicates.toArray(new Predicate[] {}));
            }

            /**
             * Engade un predicado para unha condifición de tipo ILIKE.
             * Se o campo está baleiro, non se engade.
             * 
             * @param param Nome do campo a filtrar
             * @param value Texto a filtrar
             * @param root Tipo de elemento raíz da táboa de documentos.
             * @param builder Constructor de predicados.
             * @param predicates Predicados existentes
             */
            private void addPredicateFor(String param, String value, Root<Documento> root, CriteriaBuilder builder, List<Predicate> predicates) {
                if(!StringUtils.isEmpty(value)){
                    Expression<String> path = root.get(param).as(String.class);
                    predicates.add(PredicateUtils.ilike(builder, path, value));
                }
            }
        };
    }

}
