/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import org.jasig.cas.client.authentication.AttributePrincipal;
import org.jasig.cas.client.validation.Assertion;
import org.junit.Test;
import org.springframework.security.cas.authentication.CasAssertionAuthenticationToken;
import org.springframework.security.core.userdetails.UserDetails;

import es.xunta.amtega.codapp.autorizacion.AuthorizationService;

public class CasAuthenticationUserDetailsServiceImplTest {
	
	private AuthorizationService authorizationService;

	public CasAuthenticationUserDetailsServiceImplTest() {
		authorizationService = mock(AuthorizationService.class);
	}

    @Test
    public void loadUserDetailsShouldReturnAnInstance() {
        //given: declaramos provider
        CasAuthenticationUserDetailsServiceImpl provider = new CasAuthenticationUserDetailsServiceImpl(authorizationService);
        
        CasAssertionAuthenticationToken authentication = new CasAssertionAuthenticationToken(new DummyAssertion(), "ticket-val");
        
        //when: realizamos autenticación
         UserDetails result = provider.loadUserDetails(authentication);
        
        //then: validamos que o resultado non sexa nulo e o principal sexa de tipo CustomUserDetails
        assertThat(result, is(notNullValue()));
        assertThat(result, instanceOf(CustomUserDetails.class));
    }
    
    
    
    private class DummyAssertion implements Assertion {
		private static final long serialVersionUID = 1L;

		@Override
        public boolean isValid() {
            return true;
        }
        
        @Override
        public Date getValidUntilDate() {
            return null;
        }
        
        @Override
        public Date getValidFromDate() {
            return null;
        }
        
        @Override
        public AttributePrincipal getPrincipal() {
            return new AttributePrincipal() {
                private static final long serialVersionUID = 2734910767671951914L;
                
                @Override
                public String getName() {
                    return "name";
                }
                @Override
                public String getProxyTicketFor(String service) {
                    return "service";
                }
                @Override
                public Map<String, Object> getAttributes() {
                    return new HashMap<>();
                }
            };
        }
        
        @Override
        public Date getAuthenticationDate() {
            return null;
        }
        
        @Override
        public Map<String, Object> getAttributes() {
            return null;
        }
    }
}
