/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.*;

import java.io.IOException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpSessionContext;

import org.junit.Before;
import org.junit.Test;
import org.springframework.security.core.AuthenticationException;

@SuppressWarnings("deprecation")
public class CustomAuthenticationFailureHandlerTest {
	
	private CustomAuthenticationFailureHandler instance;

	@Before
	public void setUp() {
	    instance = new CustomAuthenticationFailureHandler();
	}

    @Test
    public void onAuthenticationFailureTest() throws IOException, ServletException {
        HttpServletRequest request = mock(HttpServletRequest.class);
        HttpSession session = new TestHttpSession();
        when(request.getSession(anyBoolean())).thenReturn(session);
        HttpServletResponse response = mock(HttpServletResponse.class);
        TestException exception = new TestException();
        
        // Inicio
        assertThat(session.getAttribute(CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_ATTR), is(nullValue()));
        
        // Intentamos
        for(int i=1; i<=CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_THRESHOLD; i++) {
            instance.onAuthenticationFailure(request, response, exception);
            assertThat((Integer)session.getAttribute(CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_ATTR), is(i));
            if(i<CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_THRESHOLD) {
                assertThat(session.getAttribute(CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_HUMAN_ATTR), is(nullValue()));
            } else {
                assertThat(session.getAttribute(CustomAuthenticationFailureHandler.LOGIN_ATTEMPTS_HUMAN_ATTR), is(notNullValue()));
            }
        }
    }
    
    
    
    private class TestException extends AuthenticationException {
        private static final long serialVersionUID = 2780491057768438922L;
        public TestException() {
            super("TEST");
        }
    }

    private class TestHttpSession implements HttpSession {
        
        private Map<String,Object> attrs = new HashMap<>();

        @Override
        public Object getAttribute(String name) {
            return attrs.get(name);
        }
        @Override
        public void setAttribute(String name, Object value) {
            attrs.put(name, value);
        }
        
        @Override
        public long getCreationTime() {
            throw new UnsupportedOperationException();
        }
        @Override
        public String getId() {
            throw new UnsupportedOperationException();
        }
        @Override
        public long getLastAccessedTime() {
            throw new UnsupportedOperationException();
        }
        @Override
        public ServletContext getServletContext() {
            throw new UnsupportedOperationException();
        }
        @Override
        public void setMaxInactiveInterval(int interval) {
            throw new UnsupportedOperationException();
        }
        @Override
        public int getMaxInactiveInterval() {
            throw new UnsupportedOperationException();
        }
        @Override
        public HttpSessionContext getSessionContext() {
            throw new UnsupportedOperationException();
        }
        @Override
        public Object getValue(String name) {
            throw new UnsupportedOperationException();
        }
        @Override
        public Enumeration<String> getAttributeNames() {
            throw new UnsupportedOperationException();
        }
        @Override
        public String[] getValueNames() {
            throw new UnsupportedOperationException();
        }
        @Override
        public void putValue(String name, Object value) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void removeAttribute(String name) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void removeValue(String name) {
            throw new UnsupportedOperationException();
        }
        @Override
        public void invalidate() {
            throw new UnsupportedOperationException();
        }

        @Override
        public boolean isNew() {
            throw new UnsupportedOperationException();
        }
        
    }
}
