/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;

import org.junit.Test;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;

import es.xunta.amtega.codapp.autorizacion.AuthorizationService;

public class CustomAuthenticationProviderImplTest {

    private AuthorizationService authorizationService;

    public CustomAuthenticationProviderImplTest() {
        authorizationService = mock(AuthorizationService.class);
    }

    @Test
    public void authenticateShouldReturnAuthentication() {
        // given: declaramos provider
        AuthenticationProvider authenticationProvider = new CustomAuthenticationProviderImpl(authorizationService);
        Authentication authentication = new UsernamePasswordAuthenticationToken("user", "pass", null);

        // when: realizamos autenticación
        Authentication result = authenticationProvider.authenticate(authentication);

        // then: validamos que o resultado non sexa nulo e o principal sexa de tipo CustomUserDetails
        assertThat(result, is(notNullValue()));
        assertThat(result.getPrincipal(), instanceOf(CustomUserDetails.class));
    }

}
