/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.junit.Assert.fail;
import java.util.ArrayList;
import java.util.Collection;

import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;

public class CustomUserDetailsImplTest {
    
    private static final String NOMBRE = "nombre";
    private static final String APELLIDOS = "apellidos";
    private static final String NIF = "nif";
    private static final String USERNAME = "username";
    private static final Collection<GrantedAuthority> AUTHORITIES = new ArrayList<>();
    
    @Rule
    public ExpectedException thrown = ExpectedException.none();
    
    private CustomUserDetailsImpl instance;
    
    public CustomUserDetailsImplTest() {
        GrantedAuthority auth = new SimpleGrantedAuthority("ROLE");
        AUTHORITIES.add(auth);
    }
    
    @Before
    public void setUp() {
        instance = new CustomUserDetailsImpl(NOMBRE, APELLIDOS, NIF, USERNAME, AUTHORITIES);
    }

    @Test
    public void testIdentificador() {
        assertThat(instance.getIdentificador(), is(USERNAME));
    }

    @Test
    public void testNombre() {
        assertThat(instance.getNombre(), is(NOMBRE));
    }

    @Test
    public void testApellidos() {
        assertThat(instance.getApellidos(), is(APELLIDOS));
    }

    @Test
    public void testNif() {
        assertThat(instance.getNif(), is(NIF));
    }

    @Test
    public void testNombreNotNull() {
        thrown.expect(IllegalArgumentException.class);
        new CustomUserDetailsImpl(null, APELLIDOS, NIF, USERNAME, AUTHORITIES);
        fail("O nome non pode ser nulo, debe lanzarse unha excepción");
    }

    @Test
    public void testNombreNotEmpty() {
        thrown.expect(IllegalArgumentException.class);
        new CustomUserDetailsImpl("", APELLIDOS, NIF, USERNAME, AUTHORITIES);
        fail("O nome non pode ser nulo, debe lanzarse unha excepción");
    }
    
}
