/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autenticacion.web;

import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultHandlers.print;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.forwardedUrl;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.view;

import java.security.Principal;

import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;
import org.springframework.web.servlet.view.InternalResourceViewResolver;

public class LoginControllerTest {

    @Mock
    private Principal principal;

    private MockMvc mockMvc;

    @InjectMocks
    private LoginController loginController;

    private static final String VIEW_PREFIX = "/WEB-INF/view/";
    private static final String VIEW_SUFFIX = ".html";
    private static final String LOGIN_URL = "/login";

    @Before
    public void setup() {
        // Cando se crea un test no que a vista e a UTL teñen o mesmo valor, MockMvc xera un erro de tipo:
        //   javax.servlet.ServletException: Circular view path [login]: would dispatch back to the current
        //   handler URL [/login] again. Check your ViewResolver setup!
        //   (Hint: This may be the result of an unspecified view, due to default view name generation.)
        // A solución é engadir un InternalResourceViewResolver coa extención e a ruta dos arquivos da vista
        InternalResourceViewResolver viewResolver = new InternalResourceViewResolver();
        viewResolver.setPrefix(VIEW_PREFIX);
        viewResolver.setSuffix(VIEW_SUFFIX);

        // Procesa anotacións mock
        MockitoAnnotations.initMocks(this);
        this.mockMvc = MockMvcBuilders.standaloneSetup(loginController).setViewResolvers(viewResolver).build();
    }

    @Test
    public void loginForGetWithPrincipal() throws Exception {
        //given: login con usuario (principal)
        
        //when: realizamos a petición de login
        this.mockMvc.perform((get(LOGIN_URL).principal(principal)))
        //then: redirección ao índice
            .andExpect(forwardedUrl(null))
            .andExpect(view().name("redirect:/"))
            .andExpect(status().isFound())
            .andDo(print());
    }

    @Test
    public void loginForGetWithoutPrincipal() throws Exception {
        //given: login sen usuario
        
        //when: realizamos a petición de login
        this.mockMvc.perform((get(LOGIN_URL)))
        //then: validamos que voltamos ao login
            .andExpect(forwardedUrl(VIEW_PREFIX + "login" + VIEW_SUFFIX))
            .andExpect(view().name("login"))
            .andExpect(status().isOk())
            .andDo(print());
    }
    
}
