/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.autorizacion;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import org.junit.Test;

import es.xunta.amtega.transversal.authorization.Policy;

public class CustomAuthoritiesProviderTest {
    
    @Test
    public void getAuthoritiesShouldReturnPolicy() {
        //given: declaramos un provider
        CustomAuthoritiesProvider provider = new CustomAuthoritiesProvider();
        
        //when: recuperamos os permisos
        Policy policy = provider.getAuthorities(null, null);
        
        //then: validamos que o resultado non sexa nulo
        assertThat(policy, is(notNullValue()));
    }
    
    @Test
    public void getPriorityShouldReturnPriority() {
        //given: declaramos un provider
        CustomAuthoritiesProvider provider = new CustomAuthoritiesProvider();
        
        //when: obtemos a prioridad
        int priority = provider.getPriority();
        
        //then: validamos que o resultado sexa o axeitado
        assertThat(priority, is(100));
    }
    
    @Test
    public void supportsShouldReturnFalse() {
        //given: declaramos un provider
        CustomAuthoritiesProvider provider = new CustomAuthoritiesProvider();
        
        //when: obtemos o support
        boolean supports = provider.supports(Integer.class);
        
        //then: validamos o resultado
        assertThat(supports, is(false));
    }
    
    @Test
    public void supportsShouldReturnTrue() {
        //given: declaramos un provider
        CustomAuthoritiesProvider provider = new CustomAuthoritiesProvider();
        
        //when: obtenemos el support
        boolean supports = provider.supports(String.class);
        
        //then: validamos el resultado
        assertThat(supports, is(true));
    }
}
