/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.TestExecutionListeners;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.support.DependencyInjectionTestExecutionListener;
import org.springframework.test.context.support.DirtiesContextTestExecutionListener;
import org.springframework.test.context.transaction.TransactionalTestExecutionListener;
import org.springframework.transaction.annotation.Transactional;

import com.github.springtestdbunit.DbUnitTestExecutionListener;
import com.github.springtestdbunit.annotation.DatabaseSetup;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(locations="/spring/database.xml")
@Transactional
@TestExecutionListeners({
    DependencyInjectionTestExecutionListener.class,
    DirtiesContextTestExecutionListener.class,
    TransactionalTestExecutionListener.class,
    DbUnitTestExecutionListener.class })
@DatabaseSetup("/bbdd/archam.xml")
public class DocumentoRepositoryTest {
    
    @Autowired
    private DocumentoRepository documentoRepository;
    
    private Pageable pageable;
    
    private static final Long TOTAL_ELEMENTS = 3L;
    private static final String FILTER_TITLE = "foo1";
    private static final Long FILTER_TITLE_ELEMENTS = 1L;

    @Before
    public void setUp() {
        pageable = new PageRequest(0, 10);
    }

    @Test
    public void testFindAll() {
        DocumentoFilter filter = new DocumentoFilter();
        Page<Documento> docs = documentoRepository.findAll(DocumentoSpecifications.filterBy(filter), pageable);
        assertThat(docs.getTotalElements(), is(TOTAL_ELEMENTS));
    }

    @Test
    public void testFindAllByTitle() {
        DocumentoFilter filter = new DocumentoFilter();
        filter.setTitulo(FILTER_TITLE);
        Page<Documento> docs = documentoRepository.findAll(DocumentoSpecifications.filterBy(filter), pageable);
        assertThat(docs.getTotalElements(), is(FILTER_TITLE_ELEMENTS));
    }

}
