/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;

import org.junit.Test;

public class DocumentoTest {
    
    @Test
    public void setIdShouldReturnSameId() {
        //given: id do documento
        Long id= 1L;
        Documento documento = new Documento();
        
        //when: indicamos o valor
        documento.setId(id);
        
        //then: recuperamos o mesmo valor
        assertThat(documento.getId(), is(id));
    }
    
    @Test
    public void setUuidShouldReturnSameUuid() {
        //given: Uuid do documento
        String uuid = "Uuid";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setUuid(uuid);

        //then: recuperamos o mesmo valor
        assertThat(documento.getUuid(), is(uuid));
    }
    
    @Test
    public void setTituloShouldReturnSameTitulo() {
        //given: titulo do documento
        String titulo = "titulo";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setTitulo(titulo);

        //then: recuperamos o mesmo valor
        assertThat(documento.getTitulo(), is(titulo));
    }   
    
    @Test
    public void setDescripcionShouldReturnSameDescripcion() {
        //given: descripción do documento
        String descripcion = "Descripcion";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setDescripcion(descripcion);

        //then: recuperamos o mesmo valor
        assertThat(documento.getDescripcion(), is(descripcion));
    }   
    
    @Test
    public void setNombreShouldReturnSameNombre() {
        //given: Nombre do documento
        String nombre = "Nombre";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setNombre(nombre);

        //then: recuperamos o mesmo valor
        assertThat(documento.getNombre(), is(nombre));
    }   
    
    @Test
    public void setFormatoShouldReturnSameFormato() {
        //given: formato do documento
        String formato = "formato";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setFormato(formato);

        //then: recuperamos o mesmo valor
        assertThat(documento.getFormato(), is(formato));
    }
    
    @Test
    public void setPathShouldReturnSamePath() {
        //given: Path do documento
        String path = "Path";
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setPath(path);

        //then: recuperamos o mesmo valor
        assertThat(documento.getPath(), is(path));
    }   
    
    @Test
    public void setVersionShouldReturnSameVersion() {
        //given: Version do documento
        Long version = 1L;
        Documento documento = new Documento();

        //when: indicamos o valor
        documento.setVersion(version);

        //then: recuperamos o mesmo valor
        assertThat(documento.getVersion(), is(version));
    }
    
    @Test
    public void setSameIdsShouldReturnSameHashCode() {
        //given: Ids dos documentos
        Long id = 1L;
        Documento doc1 = new Documento();
        Documento doc2 = new Documento();
        
        //when: indicamos os ids aos documentos
        doc1.setId(id);
        doc2.setId(id);
        
        //then: hashCode é o memso
        assertThat(doc1.hashCode(), is(doc2.hashCode()));
    }
    
    @Test
    public void setDifferentIdsShouldReturnDifferentHashCode() {
        //given: Ids dos documentos
        Long id1 = 1L;
        Long id2 = 2L;
        Documento doc1 = new Documento();
        Documento doc2 = new Documento();

        //when: indicamos os ids aos documentos
        doc1.setId(id1);
        doc2.setId(id2);

        //then: hashCode NON é o memso
        assertThat(doc1.hashCode(), is(not(doc2.hashCode())));
    }   
    
    @Test
    public void equalsDocumentsShouldReturnTrue() {
        //given: Id do documento
        Long id = 1L;
        Documento doc = new Documento();

        //when: indicamos os ids aos documentos
        doc.setId(id);
        
        //then: equals devuelve verdadero
        assertThat(doc.equals(doc), is(true));
    }
    
    @Test
    public void diferentDocumentsShouldReturnFalse() {
        //given: Id do documento
        Long id1 = 1L;
        Long id2 = 2L;
        Documento doc1 = new Documento();
        Documento doc2 = new Documento();

        //when: indicamos os ids aos documentos
        doc1.setId(id1);
        doc2.setId(id2);
        
        //then: equals devuelve verdadero
        assertThat(doc1.equals(doc2), is(false));
    }
    
    @Test
    public void diferentObjectsShouldReturnFalse() {
        //given: Id do documento
        Long id = 1L;
        Documento doc = new Documento();

        //when: indicamos os ids aos documentos
        doc.setId(id);
        
        //then: equals devuelve verdadero
        assertThat(doc.equals(new Object()), is(false));
    }
    
    @Test
    public void setDocumentoValidateToString() {
        //given: documento
        Documento doc = new Documento();
        String documentFormatString = String.format("%s", doc);
        
        //when: chamamos ao método toString
        String documentToString = doc.toString();
        
        //then:
        assertThat(documentToString, is(documentFormatString));
    }
    
}
