/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.documentos.listener;

import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.assertThat;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import org.apache.logging.log4j.Level;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.core.Appender;
import org.apache.logging.log4j.core.LogEvent;
import org.apache.logging.log4j.core.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

import es.xunta.amtega.codapp.documentos.Documento;
import es.xunta.amtega.transversal.archam.core.io.StorageManager;

@RunWith(MockitoJUnitRunner.class)
@SuppressWarnings("deprecation")
public class BibliotecaDocumentosEventListenerTest {

    BibliotecaDocumentosEventListener listener = new BibliotecaDocumentosEventListener(mock(StorageManager.class));

    @Mock
    private Appender mockAppender;

    @Captor
    ArgumentCaptor<LogEvent> captorLoggingEvent;
    
    private Logger logger;

    @Before
    public void setup() {
        // prepare the appender so Log4j likes it
        when(mockAppender.getName()).thenReturn("MockAppender");
        when(mockAppender.isStarted()).thenReturn(true);
        when(mockAppender.isStopped()).thenReturn(false);

        logger = (Logger) LogManager.getLogger(BibliotecaDocumentosEventListener.class);
        logger.addAppender(mockAppender);
        logger.setLevel(Level.INFO);
    }

    @After
    public void tearDown() {
        // the appender we added will sit in the singleton logger forever
        // slowing future things down - so remove it
        logger.removeAppender(mockAppender);
    }

    @Test
    public void handleCreatedEvent() {

        // given: Creamos un evento
        Documento doc = new Documento();
        doc.setId(1L);
        DocumentoCreadoEvent event = new DocumentoCreadoEvent(doc);

        // when: Llamamos al handle
        listener.handle(event);

        // then: validar la salida del log
        String result = String.format("Creouse un novo documento con ID '%s'", doc.getId());
        verifyLogMessages(Level.INFO, result);
    }

    @Test
    public void handleUpdatedEvent() {

        // given: Creamos un evento
        Documento doc = new Documento();
        doc.setId(1L);
        DocumentoModificadoEvent event = new DocumentoModificadoEvent(doc);

        // when: Llamamos al handle
        listener.handle(event);

        // then: validar la salida del log
        String result = String.format("Actualizouse o documento con ID '%s'", doc.getId());
        verifyLogMessages(Level.INFO, result);
    }

    @Test
    public void handleDeletedEvent() {

        // given: Creamos un evento
        Documento doc = new Documento();
        doc.setId(1L);
        DocumentoEliminadoEvent event = new DocumentoEliminadoEvent(doc);

        // when: Llamamos al handle
        listener.handle(event);

        // then: validar la salida del log
        String result = String.format("Eliminouse o documento con ID '%s'", doc.getId());
        verifyLogMessages(Level.INFO, result);
    }

    @Test
    public void handleFailDeletedEvent() {

        // given: Creamos un evento
        Documento doc = new Documento();
        doc.setId(1L);
        DocumentoEliminadoEvent event = new DocumentoEliminadoEvent(doc);

        // when: Llamamos al handle
        listener.handleFail(event);

        // then: validar la salida del log
        String result = String.format("Non se puido eliminar o documento con ID '%s'", doc.getId());
        verifyLogMessages(Level.WARN, result);
    }

    /**
     * Valida os mensaxes de log por orden
     *
     * @param level Nivel de log
     * @param messages Mensaxes
     */
    private void verifyLogMessages(Level level, String... messages) {
        verify(mockAppender, times(messages.length)).append(captorLoggingEvent.capture());

        int i = 0;
        for (LogEvent loggingEvent : captorLoggingEvent.getAllValues()) {
            assertThat(loggingEvent.getMessage().getFormattedMessage(), is(messages[i++]));
            assertThat(loggingEvent.getLevel(), is(level));
        }
    }
}
