/* Amtega Archetype for Spring-Web Applications
*
* Copyright (C) 2017 AMTEGA - Xunta de Galicia <componentes-transversais.amtega@xunta.gal>
*
* This file is part of "Amtega Archetype for Spring-Web Applications".
*
* "Amtega Archetype for Spring-Web Applications" is free software: you can redistribute it
* and/or modify it under the terms of:
* Apache License, Version 2.0 (the "License");
* or the European Union Public License, either Version 1.1 or – as soon
* they will be approved by the European Commission - subsequent versions of
* the EUPL;
*
* "Amtega Archetype for Spring-Web Applications" is distributed in the hope that
* it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* Apache Software License or European Union Public License for more details.
*
* You may obtain a copy of the Apache License, Version 2.0 at:
* http://www.apache.org/licenses/LICENSE-2.0
*
* You may obtain a copy of the European Union Public Licence at:
* http://joinup.ec.europa.eu/software/page/eupl/licence-eupl
*/

package es.xunta.amtega.codapp.inicio.web;

import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.result.MockMvcResultHandlers.print;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.forwardedUrl;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.view;

import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.MockitoAnnotations;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;

public class InicioControllerTest {

    private static final String INDEX_URL = "index";
    private static final String INDEX_VIEW = "index";
    
    private MockMvc mockMvc;
    
    @InjectMocks
    private InicioController controller;
    
    @Before
    public void setup() {
        // Process mock annotations
        MockitoAnnotations.initMocks(this);
        this.mockMvc = MockMvcBuilders.standaloneSetup(controller).build();
    }
    
    /**
     * Valida el método configuración get está permitido para la url /configuracion
     * Se valida que el modelo contiene los atributos esperados
     * @throws Exception excepción
     */
    @Test
    public void intexForGet() throws Exception {
        //given: nada
        
        //when: petición GET ao índice
        this.mockMvc.perform((get("/")))
        //then: vistas, variables e estado correctos
            .andExpect(forwardedUrl(INDEX_URL))
            .andExpect(view().name(INDEX_VIEW))
            .andExpect(status().isOk())
            .andDo(print());
    }
    
    /**
     * Valida que el método POST no está permitido para la url /configuracion
     * Se valida que el modelo contiene los atributos esperados
     * @throws Exception excepción
     */    
    @Test
    public void indexForPost() throws Exception {
        //given: nada
        
        //when: petición POST ao índice
        this.mockMvc.perform((post("/")))
        //then: vistas, variables e estado correctos
            .andExpect(forwardedUrl(INDEX_URL))
            .andExpect(view().name(INDEX_VIEW))
            .andExpect(status().isOk())
            .andDo(print());
    }    
}
